* This file calculates means (and for some variables variances) of all
* variables in the micro-data in order to check for consistency of the 
* variable definitions over time.
* MS 9/2006, revised TvR 2/2007

*version 7.0
set memory 20m
set more off

cap log close
log using check_consistency, text replace

local dtapath = "../data_monthly_clean/"
local outputfilepath = "../data_secondary/"

do define_months.do


*********************************************************************************
* Make a dataset to gather means:
*********************************************************************************

clear
gen int year = .
saveold "`outputfilepath'meansdata", replace


*********************************************************************************
* Loop over datasets to calculate means (and standard deviations):
*********************************************************************************

forvalues j= 228/558 {
global t_4 "`j'"

local yymm = substr(string(${x${t_4}}),3,4)
disp("`yymm'")

clear
use "`dtapath'clean_`yymm'"

* Consider only sample for wage series:
drop if wage==.
drop if cow_selfempl
drop if ~lfstat_empl_4

* Generate mean for all variables:
foreach VAR of varlist * {
	qui su `VAR'
	qui gen m_`VAR' = r(mean) in 1
}

* Generate standard deviation for earnings, hours and wages:
foreach VAR of varlist earnwke uhours1e w_* rw_* wage* {
	qui su `VAR'
	qui gen sd_`VAR' = r(sd) in 1
}

* Save secondary dataset:

keep year month m_* sd_*
qui keep in 1
qui gen time = year + (month-1)/12

append using "`outputfilepath'/meansdata"
qui saveold "`outputfilepath'meansdata", replace

}	/* end loop over datasets */


clear
use "`outputfilepath'meansdata"
compress
order year month
sort year month

saveold "`outputfilepath'meansdata", replace
outsheet using "`outputfilepath'meansdata.csv", comma replace


*********************************************************************************
* Graph means and standard deviations:
*********************************************************************************

local outputfilepath = "../data_secondary/"
clear
use "`outputfilepath'meansdata"

pause on

foreach VAR of varlist m_* sd_* {
	sort time
	gen nonmissing = 0 in 1
	replace nonmissing = nonmissing[_n-1] - (`VAR'==.) if nonmissing[_n-1]~=.
	sort nonmissing time
	graph7 `VAR' time, sy(dddd) c(LLLL) xlabel(1979 1981 to 2007) ylabel
	cap graph7 `VAR' `VAR'_cepr time, sy(dodo) c(LLLL) xlabel(1979 1981 to 2007) ylabel
	pause
	drop nonmissing
}

local outputfilepath = "../data_secondary/"
clear
use "`outputfilepath'meansdata"
foreach VAR of varlist m_* sd_* {
	cap graph7 `VAR' `VAR'_cepr, xlabel ylabel
	pause
}

