* This file renames variables, creates new variables, 
* corrects for errors in existing variables
* Missing values are coded as missing (rather than negative values)
* Dummies are defined as such (rather than as 1 or 2)
* MS 9/2006, revised TvR 12/2006

*version 7.0
set mem 35m
set more off
pause on

cap log close
log using make_consistent, text replace

global dat_path          "../data_matched_all/"       /* where dta files are located */
global sav_path          "../data_monthly/"           /* where consistent monthly data files are to be saved */
global do_path           ""                 		/* where auxilliary do-files are located */

cap program drop make_consistent
program define make_consistent

* define macros for merging period
global t_4 "`1'"
global t_3 =  ${t_4}-1
global t_2 =  ${t_3}-1
global t_1 =  ${t_2}-1

global year = substr(string(${x${t_4}}),1,4)
local  yymm = substr(string(${x${t_4}}),3,4)
local month = substr(string(${x${t_4}}),5,2)
display "`yymm'"
use "${dat_path}cepr_merged_`yymm'", clear

quietly {	/* BEGIN QUIETLY */


******************************************************************************************
* DATE, AGE, REGION, STATE AND HOUSING TENURE

gen int year=0
gen byte hetenure=.

if     ${x${t_4}}>=197901 & ${x${t_4}}<=197912   {
	replace year=h_year_4+1970 
}
else if ${x${t_4}}>=198001 & ${x${t_4}}<=198912 {
	replace year=h_year_4+1980 
}
else if ${x${t_4}}>=198201 & ${x${t_4}}<=198812 {
	replace hetenure=hetenure_4-6 if hetenure_4>=6 & hetenure_4<=8
	drop hetenure_*
}
else if  ${x${t_4}}>=199001 & ${x${t_4}}<=199312 {
	replace year=h_year_4+1990 
}
if  ${x${t_4}}>=199401 & ${x${t_4}}<=199712 {
	replace year=hryear_4+1900
	replace hetenure=hetenure_4 if hetenure_4>=1 & hetenure_4<=3
	drop hetenure_*
}
else if ${x${t_4}}>=199801 {
	replace year=hryear4_4
	replace hetenure=hetenure_4 if hetenure_4>=1 & hetenure_4<=3
	drop hetenure_*
}
replace year=${year} if year==.

cap drop h_year_*
cap drop hryear_*
cap ren h_month_4 month         /* 1989 - 1993 */
cap ren hrmonth_4 month         /* 1979 - 1988 and 1994 - 2006 */
cap drop h_month_*
cap drop hrmonth_*
replace month = `month' if month==.

cap gen year_cepr = .
cap gen month_cepr = .

* age
ren age_4 age
drop age_*
replace age = . if age<=0
cap gen age_cepr = .

* region, state and housing tenure
if ${x${t_4}}>=198901 & ${x${t_4}}<=199312  {
    rename hg_reg_4 gereg
    cap drop gereg_*
    cap drop hg_reg_*
    replace hetenure=hdtenure_4 if hdtenure_4>=1 & hdtenure_4<=3
    drop hdtenure_*
    }
else {
    rename gereg_4 gereg
    cap drop gereg_*
}
replace gereg = . if gereg<=0
replace state = . if state<=0
replace hetenure = . if hetenure<=0

count if gereg ~=.
local regionnm = r(N)
count if state ~=.
local statenm = r(N)
if `regionnm' < 50 | `statenm' < 50 {
	/* must be mismatches */
	replace gereg = .
	replace state = .
}


******************************************************************************************
* WEIGHTS

if ${x${t_4}}>=197901 & ${x${t_4}}<=198212 {
	cap gen fnlwgt_4 = .
	ren  fnlwgt_4 weight
	ren fnlwgt_cepr weight_cepr
	cap drop fnlwgt_*
	ren orgwgt_cepr earnwt_cepr
}
else if ${x${t_4}}>=198301 & ${x${t_4}}<=198812 {
	cap gen fnlwgt_4 = .
	cap gen ernlwt_4 = .
	ren  fnlwgt_4 weight
	ren fnlwgt_cepr weight_cepr
	ren  ernlwt_4 earnwt
	ren orgwgt_cepr earnwt_cepr
	cap drop fnlwgt_*
	cap drop ernlwt_*
}
else if ${x${t_4}}>=198901 & ${x${t_4}}<=199312 {
	ren  a_fnlwgt_4 weight
	ren fnlwgt_cepr weight_cepr
	ren  a_ernlwt_4 earnwt
	ren orgwgt_cepr earnwt_cepr
	cap drop a_fnlwgt_*
	cap drop a_ernlwt_*
}
else if ${x${t_4}}>=199401  {
	ren  pwsswgt_4 weight
	ren  pworwgt_4 earnwt
	if ${x${t_4}}<=200512  {
		ren fnlwgt_cepr weight_cepr
		ren orgwgt_cepr earnwt_cepr
	}
	if ${x${t_4}}<=200212  {
		ren pwlgwgt_4 longwt
	}
	cap drop pwsswgt_*
	cap drop pworwgt_*
	cap drop pwlgwgt_*
}
cap gen earnwt = .
cap gen longwt = .
cap gen weight_cepr = .
cap gen earnwt_cepr = .

******************************************************************************************
* DEMOGRAPHY

* sex
gen female = (sex_4==2)
replace female = . if sex_4==. | sex_4<=0
drop sex_*
cap gen byte female_cepr = .

* race
* create a race variable which is consistently coded over the whole sampling period
* it has three values: 1=white, 2=black, 3=other

if ${x${t_4}}>=197901 & ${x${t_4}}<=198812 {
	gen byte race=race_rcde_4
	drop race_rcde_*
}
else if ${x${t_4}}>=198901 & ${x${t_4}}<=199512 {
	gen byte race=race82_4
	replace race=3 if race82_4==4 | race82_4==5
	drop race82_*
}
else if ${x${t_4}}>=199601 & ${x${t_4}}<=200212 {
	gen byte race=race96_4
	replace race=3 if race96_4==4
	drop race96_*
}
else if ${x${t_4}}>=200301 {
	gen byte race=prdtrace_4
	replace race=1 if prdtrace_4==6  | prdtrace_4==7  | prdtrace_4==8 | prdtrace_4==9 /* white */
	replace race=2 if prdtrace_4==10 | prdtrace_4==11 | prdtrace_4==12                /* black */
	replace race=3 if prdtrace_4==13 | prdtrace_4==5  | prdtrace_4==14                /* asian to other */
	replace race=3 if prdtrace_4>=15 & prdtrace_4<=21                                 /* other */
	drop prdtrace_*
}
replace race = . if race<=0
gen byte race_black = (race==2)
gen byte race_nonwhite = (race==2 | race==3)

* hispanic
if ${x${t_4}}<=200512 {
	gen byte hispanic_cepr = (wbho_cepr==3)
}
else {
	gen wbho_cepr = .
	gen byte hispanic_cepr = .
}

* marital status
* 1 = married, spouse present
* 2 = married, spouse absent (incl separated)
* 3 = widowed or divorced
* 4 = never married
if ${x${t_4}}>=197901 & ${x${t_4}}<=198112 {
	ren maritl78_4 a_maritl_4
}
if ${x${t_4}}>=197901 & ${x${t_4}}<=199312  {
	* 1=married, civ. spouse present, 2=married, armed sp. pres., 3.=married, spouse abs.(incl. seperated), 4=widowed or divorced, 5=never married
	* 1=married, civ. spouse present, 2=married, armed sp. pres., 3=married, sp. abs (w/o sep.), 4=widowed, 5=divorced,6=seperated,7=never married
	gen byte maritl=.
	replace maritl=1 if a_maritl_4==1 | a_maritl_4==2
	replace maritl=2 if a_maritl_4==3 | a_maritl_4==6
	replace maritl=3 if a_maritl_4==4 | a_maritl_4==5
	replace maritl=4 if a_maritl_4==7
	drop a_maritl_*
}
if ${x${t_4}}==198711 {
	drop maritl
	gen maritl=maritl_nber-1
	replace maritl=1 if maritl_nber==1
	replace maritl=4 if maritl_nber==7
	drop maritl_nber
}
if ${x${t_4}}>=199401 & ${x${t_4}}<=200612 {
	* 1=married, spouse pres., 2=married, sp. abs., 3=widowed, 4=divorced, 5=seperated, 6=never married
	gen byte maritl=pemaritl_4
	replace maritl=2 if pemaritl_4==5
	replace maritl=3 if pemaritl_4==4
	replace maritl=4 if pemaritl_4==6
	drop pemaritl_*
}
replace maritl = . if maritl<=0
gen byte married = (maritl>=1 & maritl<=3)
replace married=. if maritl==.
gen byte married_spouse = (maritl==1)
replace married_spouse=. if maritl==.


******************************************************************************************
* EDUCATION

* correction for coding change in 1984

if ${x${t_4}}>=197901 & ${x${t_4}}<=199112 {
	* from 1979 to 1988 different coding of education:
    	if ${x${t_4}}>=197901 & ${x${t_4}}<=198812 {
      	gen byte gradeat=a_hga_4-1
	}
    	else {
		gen byte gradeat=a_hga_4
	}
	gen byte gradecp = a_hgc_4
	drop a_hga_* a_hgc_*
	replace gradecp = . if gradecp<0
	replace gradeat = . if gradeat<0
}
if ${x${t_4}}>=199201 & ${x${t_4}}<=199312  {
	cap ren a_hga_3 a_hga_4		/* In 92:1 fourth intvw missing */
	rename a_hga_4 peeduca_4
}
if ${x${t_4}}>=199201  {
	replace peeduca_4 = . if peeduca_4<=0
}

* Generate categorical variable for education (Jaeger 97)
* 1 = dropouts
* 2 = high school
* 3 = some college
* 4 = college graduates
* 5 = academic

if ${x${t_4}}>=197901 & ${x${t_4}}<=199112 {
    gen byte educat=.
    replace educat=1 if gradeat>= 0 & gradeat<=12       /* dropouts */
    replace educat=2 if gradeat==12 & gradecp==1        /* high school */
    replace educat=3 if gradeat>=13 & gradeat<=16       /* some college */
    replace educat=4 if gradeat==16 & gradecp==1        /* college graduate */
    replace educat=4 if gradeat>=17 & gradecp~=.        /* college graduate */
    replace educat=5 if gradeat==18 & gradecp==1        /* academic */
}
if ${x${t_4}}>=199201 {
    gen byte educat=.
    replace educat=1 if peeduca_4>=31 & peeduca_4<=37   /* dropouts */
    replace educat=2 if peeduca_4==38 | peeduca_4==39   /* high school */
    replace educat=3 if peeduca_4>=40 & peeduca_4<=42   /* some college */
    replace educat=4 if peeduca_4==43 | peeduca_4==44   /* college graduate */
    replace educat=5 if peeduca_4==45 | peeduca_4==46   /* academic */
}

* education recoding to linear variable

if ${x${t_4}}>=197901 & ${x${t_4}}<=199112 {
	gen byte gradecpe = gradecp
	gen byte gradeate = gradeat
	drop gradecp gradeat
}
else if ${x${t_4}}>=199201 {
	gen byte gradeate=0
	gen byte gradecpe=2
	replace gradeate=2.5  if peeduca_4==32 
	replace gradeate=5.5  if peeduca_4==33  
	replace gradeate=7.5  if peeduca_4==34 
	replace gradeate=9  if peeduca_4==35
	replace gradeate=10 if peeduca_4==36 
	replace gradeate=11 if peeduca_4==37 
	replace gradeate=12 if peeduca_4==38 | peeduca_4==39 
	replace gradecpe=1  if peeduca_4==39
	replace gradeate=13 if peeduca_4==40 
	replace gradeate=14 if peeduca_4==41 | peeduca_4==42
	replace gradecpe=1  if peeduca_4==41 | peeduca_4==42
	replace gradeate=16 if peeduca_4==43
	replace gradecpe=1  if peeduca_4==43
	replace gradeate=18 if peeduca_4==44 | peeduca_4==45 | peeduca_4==46
	replace gradecpe=1  if peeduca_4==44 | peeduca_4==45 | peeduca_4==46
	replace gradecpe=. if peeduca_4==.
	replace gradeate=. if peeduca_4==.
	drop peeduca_*
}

replace gradecpe = 2 - gradecpe /* to make dummy */
gen byte educ_hsgrad = (educat==2)
replace educ_hsgrad = . if educat==.
gen byte educ_college = (educat==4)
replace educ_college = . if educat==.

if ${x${t_4}}<=200512 {
	ren educ_cepr educat_cepr
}
else {
	gen educat_cepr = .
}


******************************************************************************************
* LABOR FORCE STATUS, SAMEJOB VARIABLE & UNEMPLOYMENT DURATION

forvalues i=1/4 {		/* We need these ones for all four interviews */

display "t_4 is ${x${t_4}} and t_`i' is ${x${t_`i'}}"

* labor force status
* 1 = employed at work
* 2 = employed, not at work
* 3 = unemployed, on layoff
* 4 = unemployed, looking
* 5 = nilf
if ${x${t_4}}>=197901 & ${x${t_`i'}}<=198812  {
	* before 1989 there is no labor force status value for layoff
	* so we recode layoff  from adhwyabs.
	* 1=working, 2=with job not at work, 3=unempl. looking, 4=nilf house, 5=nilf school, 6=nilf unable, 7=nilf other
	replace lfsr78_`i' = . if lfsr78_`i'<=0
	replace adwhyabs_`i' = . if adwhyabs_`i'<=0
	gen byte lfstat_`i' = lfsr78_`i'
	replace  lfstat_`i'=4 if lfsr78_`i'==3
	replace  lfstat_`i'=5 if lfsr78_`i'>=4
	replace  lfstat_`i'=. if lfsr78_`i'==.
	replace  lfstat_`i'=3 if lfstat_`i'==4 & (adwhyabs_`i'==6 | adwhyabs_`i'==7)
	drop lfsr78_`i' adwhyabs_`i'
}
if ${x${t_`i'}}>=198901 & ${x${t_`i'}}<=199312  {
	* 1=working, 2=with job not at work, 3=unempl. looking, 4=unempl. on layoff, 5=nilf workin w/o pay, 6=nilf unavailable, 7=nilf other
	replace a_lfsr_`i' = . if a_lfsr_`i'<=0
	gen byte lfstat_`i'= a_lfsr_`i'
	replace  lfstat_`i'=5 if a_lfsr_`i'>=5
	replace  lfstat_`i'=3 if a_lfsr_`i'==4
	replace  lfstat_`i'=4 if a_lfsr_`i'==3
	replace  lfstat_`i'=. if a_lfsr_`i'==.
	drop a_lfsr_`i' adwhyabs_`i'
}
if ${x${t_`i'}}>=199401 {
	* 1=employed at work, 2=employed absent, 3=unempl. on layoff, 4=unempl. looking, 5=nilf retired, 6=nilf disabled, 7=nilf other
	replace pemlr_`i' = . if pemlr_`i'<=0
	gen byte lfstat_`i'=pemlr_`i'
	replace  lfstat_`i'=5 if pemlr_`i'>=5
	replace  lfstat_`i'=. if pemlr_`i'==.
}

* same information in prempnot, helps fill in some missing values
cap replace lfstat_`i' = 1 if lfstat_`i'==. & prempnot_`i'==1 
cap replace lfstat_`i' = 3 if lfstat_`i'==. & prempnot_`i'==2 
count if lfstat_`i'~=.
if r(N)<50 {
	replace lfstat_`i'=.  /* must be mismatches */
}

* create dummies for labor force status:
gen byte lfstat_empl_`i' = (lfstat_`i'==1 | lfstat_`i'==2)
gen byte lfstat_unem_`i' = (lfstat_`i'==3 | lfstat_`i'==4)
gen byte lfstat_layf_`i' = (lfstat_`i'==4)
gen byte lfstat_nilf_`i' = (lfstat_`i'==5)

if `i'==4 & ${x${t_4}}<=200512 {
	* CEPR lfstat variable includes only three categories:
	replace lfstat_cepr = 5 if lfstat_cepr==3
	replace lfstat_cepr = 3 if lfstat_cepr==2
	gen byte lfstat_empl_cepr = (lfstat_cepr==1)
	gen byte lfstat_unem_cepr = (lfstat_cepr==3)
	gen byte lfstat_nilf_cepr = (lfstat_cepr==5)
}
else if `i'==4 & ${x${t_4}}>=200601  {
	gen lfstat_cepr = .
	gen byte lfstat_empl_cepr = .
	gen byte lfstat_unem_cepr = .
	gen byte lfstat_nilf_cepr = .
}	

* samejob variable
if ${x${t_4}} - 4 + `i' >= 199401  {
	ren puiodp1_`i' samejob_`i'
	replace samejob_`i' = . if samejob_`i'<=0
	replace samejob_`i' = 2 - samejob_`i'  /* to make dummy */
	count if samejob_`i' ~=.
	if r(N)<50 replace samejob_`i'=.  /* must be mismatches */
}
cap gen byte samejob_`i' = .

* 312 number of weeks unemployed
if ${x${t_4}}>=197901 & ${x${t_`i'}}<=198312  {
	replace prunedur_`i'=. if prunedur_`i'<0
	replace prunedur_help_`i' = . if prunedur_help_`i'<0 /* from CEPR */
	replace prunedur_`i'=prunedur_help_`i' if prunedur_`i'==.
	drop prunedur_help_`i'
}
else if ${x${t_`i'}}>=198401 & ${x${t_`i'}}<=198812  {
	replace prunedur_`i'=. if prunedur_`i'<0
}
else if ${x${t_`i'}}>=198901 & ${x${t_`i'}}<=199312  {
	ren  a_wkslk_`i' prunedur_`i'
	replace prunedur_`i'=. if prunedur_`i'<0
}
else {
	replace prunedur_`i'=. if prunedur_`i'<0
}

}	/* end loop over 4 interviews */

* unemployment duration before a job was found
gen int unemdur=.
replace unemdur=prunedur_3 if lfstat_empl_4 & lfstat_unem_3
replace unemdur=prunedur_2 if lfstat_empl_4 & lfstat_empl_3 & lfstat_unem_2
replace unemdur=prunedur_1 if lfstat_empl_4 & lfstat_empl_3 & lfstat_empl_2 & lfstat_unem_1


******************************************************************************************
* SAMPLE SELECTION CRITERIA WAGE SERIES

* non-agricultural private sector wage and salary worker
gen noagrpws = .
if ${x${t_4}}>=198401 & ${x${t_4}}<=198812  {
	cap replace noagrpws= (noagrpws_4==1)
	cap drop noagrpws_*
}
else if ${x${t_4}}>=198901 & ${x${t_4}}<=199312 {
	replace noagrpws= (a_nagpws_4==1)
	drop a_nagpws_*
	cap drop a_nagws_*
}
else if ${x${t_4}}>=199401 {
	replace noagrpws= (prnagpws_4==1)
	drop prnagpws_* prnagws_*
}

* 174 dummy whether in civilian labor force
if ${x${t_4}}>=197901 & ${x${t_4}}<=199312  {
	replace a_civlf_4 = . if a_civlf_4<=0
	gen byte prcivlf=2
	replace  prcivlf=1 if a_civlf_4==1
	drop a_civlf_4
}
else  {
	ren prcivlf_4 prcivlf
	replace prcivlf = . if prcivlf<=0
}
replace prcivlf = 2 - prcivlf /* to make dummy */

* dummy whether in full-time labor force
cap replace prftlf_4 = . if prftlf_4<=0
cap replace prftlf_4 = 2 - prftlf_4  /* to make dummy */
cap ren prftlf_4 prftlf
cap gen prftlf = .

* class of worker
* 1 = govt federal
* 2 = govt state
* 3 = govt local
* 4 = private for profit
* 5 = private nonprofit
* 6 = self-empl incorp.
* 7 = selfempl not inc.
* 8 = without pay
if ${x${t_4}}==198711 {
	drop a_clswkr_4
	rename clswkr_nber a_clswkr_4
}
if ${x${t_4}}>=197901 & ${x${t_4}}<=199312  {
	replace a_clswkr_4 = . if a_clswkr_4<=0
	replace a_clswkr_3 = . if a_clswkr_3<=0
	gen byte cow =.
	replace cow =1 if a_clswkr_4==2
	replace cow =2 if a_clswkr_4==3
	replace cow =3 if a_clswkr_4==4
	replace cow =4 if a_clswkr_4==1
	replace cow =6 if a_clswkr_4==5
	replace cow =7 if a_clswkr_4==6
	replace cow =8 if a_clswkr_4==7
	replace cow =1 if cow==. & a_clswkr_3==2
	replace cow =2 if cow==. & a_clswkr_3==3
	replace cow =3 if cow==. & a_clswkr_3==4
	replace cow =4 if cow==. & a_clswkr_3==1
	replace cow =6 if cow==. & a_clswkr_3==5
	replace cow =7 if cow==. & a_clswkr_3==6
	replace cow =8 if cow==. & a_clswkr_3==7
	drop a_clswkr_*
}
else {
	replace peio1cow_4 = . if peio1cow_4<=0
	cap replace peio1cow_3 = . if peio1cow_3<=0
	ren peio1cow_4 cow
	cap replace cow = peio1cow_3 if cow==.
	cap drop peio1cow_*
}

* dummies for class of worker
gen byte cow_privsect = (cow==4 | cow==5)
gen byte cow_publsect = (cow==1 | cow==2 | cow==3)
gen byte cow_selfempl = (cow==6 | cow==7)

if ${x${t_4}}<=200512 {
	ren pubsect_cepr cow_publsect_cepr
	gen byte cow_selfempl_cepr = selfemp_cepr | selfinc_cepr
	drop selfemp_cepr selfinc_cepr
}
else  {
	gen byte cow_publsect_cepr = .
	gen byte cow_selfempl_cepr = .
}

* unionization
cap rename a_unem_4 a_unmem_4
if ${x${t_4}}<=198812  {
	cap rename  a_unmem_4 peernlab_4
	cap rename  a_uncov_4 peerncov_4
	cap gen peernlab_4 = .
	cap gen peerncov_4 = .
}
if ${x${t_4}}>=198901 & ${x${t_4}}<=199312 {
	rename  a_unmem_4 peernlab_4
	rename  a_uncov_4 peerncov_4
}
replace peernlab_4 = . if peernlab_4<=0
replace peerncov_4 = . if peerncov_4<=0
ren peernlab_4 unionmem
ren peerncov_4 unioncov
replace unionmem = 2 - unionmem /* to make dummy */
replace unioncov = 2 - unioncov /* to make dummy */
if ${x${t_4}}<=200512  {
	ren unmem_cepr unionmem_cepr
	ren uncov_cepr unioncov_cepr
}
else  {
	gen unionmem_cepr = .
	gen unioncov_cepr = .
}


******************************************************************************************
* EARNINGS AND HOURS

if ${x${t_4}}>=197901 & ${x${t_4}}<=198312 {
	cap ren hrlywk_4 paidhre
	cap ren herntp_4 earnhre
	cap ren prernwa_4 earnwke
	cap ren uslhrs_4 uhours1
	cap gen paidhre = .
	cap gen earnhre = .
	cap gen earnwke = .
	cap gen uhours1 = .
	gen hourslw = .
	gen uhours_topc = .
	gen earnwk_topc = .
}
else if ${x${t_4}}>=198401 & ${x${t_4}}<=198812 {
	ren hrlywk_4 paidhre
	ren herntp_4 earnhre
	ren prernwa_4 earnwke
	ren uslhrs_4 uhours1
	gen hourslw = .
	gen uhours_topc = .
	gen earnwk_topc = .
}
else if ${x${t_4}}>=198901 & ${x${t_4}}<=199312  {
	ren a_hrlywk_4 paidhre
	ren a_herntp_4 earnhre
	ren a_werntp_4 earnwke
	ren a_uslhrs_4 uhours1
	gen hourslw = .
	ren  a_herntf_4  uhours_topc
	ren  a_werntf_4  earnwk_topc
}
else if ( ${x${t_4}}>=199401 & ${x${t_4}}<=199712 ) |  ${x${t_4}}>=200301 {
	ren prernhly_4 earnhre
	ren prernwa_4 earnwke
	* ren peern_4 ptern_4         -- WHAT IS THIS??
	* ren puern2_4  ptern2_4      -- WHAT IS THIS??
}
else if ${x${t_4}}>=199801 & ${x${t_4}}<=200212 {
	ren pternhly_4 earnhre
	ren pternwa_4 earnwke
}
if ${x${t_4}}>=199401 {
	ren peernhry_4 paidhre
	* ren peernhro_4 uhours /* usual hours on all jobs */
	ren pehrusl1_4 uhours1
	ren pehract1_4 hourslw
	ren pthr_4 uhours_topc
	ren ptwk_4 earnwk_topc
}
gen uhours1e = uhours1
replace uhours1e = hourslw if uhours1==-4 /* hours vary: replace by hours worked last week */
gen byte uhours1_alloc = (uhours1==-4)
replace paidhre = . if paidhre<=0
replace paidhre = 2 - paidhre /* to make dummy */
replace earnhre = . if earnhre<=0
replace earnwke = . if earnwke<=0
replace uhours1 = . if uhours1<=0
replace uhours1e = . if uhours1e<=0
replace hourslw = . if hourslw<=0
replace uhours_topc = . if uhours_topc<=0
replace uhours_topc = 2 - uhours_topc /* to make dummy */
replace earnwk_topc = . if earnwk_topc<=0
replace earnwk_topc = 2 - earnwk_topc /* to make dummy */
if ${x${t_4}}<=200512  {
	ren prhrusl_cepr uhours1_bmd_cepr
	ren pehrusl1_cepr uhours1_cepr
	ren uhourse_cepr uhours1e_cepr
	ren uhoursi_cepr uhours1ei_cepr  /* edited and imputed, cf to our uhourse */
	* ren peernhro_cepr uhours_cepr /* usual hours on all jobs */
}
else  {
	gen paidhre_cepr = .
	gen earnhre_cepr = .
	gen earnwke_cepr = .
	gen uearnwk_cepr = .
	gen uhours1_bmd_cepr = .
	gen uhours1_cepr = .
	gen uhours1e_cepr = .
	gen uhours1ei_cepr = .
	* gen uhours_cepr = .
}


******************************************************************************************
* MATCH VARIABLES

gen byte match_any2 = 1 - (1-any2_43) * (1-any2_32) * (1-any2_21)
gen byte match_ANY2 = 1 - (1-ANY2_43) * (1-ANY2_32) * (1-ANY2_21)
gen byte match_s_r_a = 1 - (1-s_r_a_43) * (1-s_r_a_32) * (1-s_r_a_21)
gen byte match_S_R_A = 1 - (1-S_R_A_43) * (1-S_R_A_32) * (1-S_R_A_21)
if ${x${t_4}}<=200512  {
	ren merge_cepr match_cepr
	ren s_r_a_cepr match_s_r_a_cepr
}
else  {
	gen match_cepr = .
	gen match_s_r_a_cepr = .
}
ren s_r_a_43 match_s_r_a_43
ren s_r_a_32 match_s_r_a_32
ren s_r_a_21 match_s_r_a_21


******************************************************************************************
* INDUSTRY AND OCCUPATION

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
* Industry and occupation codes
* problably variables mjind78 mjocc78 dtind78 dtocc78 ind70 occ70 not correctly coded in 1983 !!!!!!!!!!!!

forvalues i=1/4 {		/* We need these ones for all four interviews */

* first make sure that industry and occupation variables exist and code missing values
* variables: indYY, occYY, dtindYY, dtoccYY, mjindYY and mjoccYY, where YY indicates year of coding
if ${x${t_4}}>=197901 & ${x${t_`i'}}<=198212 {
	gen occ92_`i'=.
	gen mjocc83_`i'=.
	gen dtocc83_`i'=.
}
if ${x${t_4}}>=197901 & ${x${t_`i'}}<=198312 {
	cap replace ind70_`i'=. if ind70_`i'<1
	cap gen ind70_`i'=.				  /* ind70 does not exist in 1983 */
	replace occ70_`i'=. if occ70_`i'<1
	replace mjind78_`i'=. if mjind78_`i'>20 | mjind78_`i'<1
	replace mjocc78_`i'=. if mjocc78_`i'>13 | mjocc78_`i'<1
	replace dtind78_`i'=. if dtind78_`i'>51 | dtind78_`i'<1
	replace dtocc78_`i'=. if dtocc78_`i'>44 | dtocc78_`i'<1
}
if ${x${t_`i'}}>=198301 & ${x${t_`i'}}<=198812 {
	replace occ80_`i'=. if occ80_`i'<1
	replace ind80_`i'=. if ind80_`i'<1
	gen occ92_`i'=.
	replace mjind83_`i'=. if mjind83_`i'>22 | mjind83_`i'<1
	replace mjocc83_`i'=. if mjocc83_`i'>15 | mjocc83_`i'<1
	replace dtind83_`i'=. if dtind83_`i'>45 | dtind83_`i'<1
	replace dtocc83_`i'=. if dtocc83_`i'>50 | dtocc83_`i'<1
	* detailed industry, recoded to code prdtind1 which is used by the 
	* BLS in the period of 1994-2002
	gen byte dtind94r_`i'=dtind83_`i'
	replace  dtind94r_`i'=dtind83_`i'+1 if dtind83_`i'>=34 & dtind83_`i'<=52
}
else if ${x${t_`i'}}>=198901 & ${x${t_`i'}}<=199112 {
	gen occ92_`i'=.
	ren a_ind_`i' ind80_`i'
	replace ind80_`i'=. if ind80_`i'<1
	ren a_occ_`i' occ80_`i'
	replace occ80_`i'=. if occ80_`i'<1
	ren a_mjind_`i' mjind83_`i'
	ren a_mjocc_`i' mjocc83_`i'
	ren a_dtind_`i' dtind83_`i'
	ren a_dtocc_`i' dtocc83_`i'
	replace mjind83_`i'=. if mjind83_`i'<1
	replace mjocc83_`i'=. if mjocc83_`i'<1
	replace dtind83_`i'=. if dtind83_`i'<1
	replace dtocc83_`i'=. if dtocc83_`i'<1
	* detailed industry, recoded to code prdtind1 which is used by the 
	* BLS  in the period of 1994-200201 
	gen byte dtind94r_`i'=dtind83_`i'
	replace  dtind94r_`i'=dtind83_`i'+1 if dtind83_`i'>=34 & dtind83_`i'<=52
}
else if ${x${t_`i'}}>=199201 & ${x${t_`i'}}<=199312  {
	ren a_ind_`i' ind92_`i'
	replace ind92_`i'=. if ind92_`i'<1
	ren a_occ_`i' occ92_`i'
	replace occ92_`i'=. if occ92_`i'<1
	ren a_mjind_`i' mjind83_`i'
	ren a_mjocc_`i' mjocc83_`i'
	ren a_dtind_`i' dtind83_`i'
	ren a_dtocc_`i' dtocc83_`i'
	replace mjind83_`i'=. if mjind83_`i'<1
	replace mjocc83_`i'=. if mjocc83_`i'<1
	replace dtind83_`i'=. if dtind83_`i'<1
	replace dtocc83_`i'=. if dtocc83_`i'<1
	* detailed industry, recoded to code prdtind1 which is used by the 
	* BLS  in the period of 1994-200201 
	gen byte dtind94r_`i'=dtind83_`i'
	replace  dtind94r_`i'=dtind83_`i'+1 if dtind83_`i'>=34 & dtind83_`i'<=52
}
else if ${x${t_`i'}}>=199401 & ${x${t_`i'}}<=199712 {
	ren peio1icd_`i' ind92_`i'
	ren peio1ocd_`i' occ92_`i'
	replace     ind92_`i'=. if ind92_`i'<1
	replace     occ92_`i'=. if occ92_`i' <1
	ren prmjind1_`i' mjind83_`i'
	ren prdtind1_`i' dtind94_`i'
	ren prmjocc1_`i' mjocc83_`i'
	ren prdtocc1_`i' dtocc83_`i'
	replace   mjind83_`i'=. if mjind83_`i'<1
	replace   mjocc83_`i'=. if mjocc83_`i'<1
	replace   dtind94_`i'=. if dtind94_`i'<1
	replace   dtocc83_`i'=. if dtocc83_`i'<1
}
else if ${x${t_`i'}}>=199801 & ${x${t_`i'}}<=200212 {
	ren peio1icd_`i' ind92_`i'
	ren ptio1ocd_`i' occ92_`i'
	replace     ind92_`i'=. if ind92_`i'<1
	replace     occ92_`i'=. if occ92_`i' <1
	ren prmjind1_`i' mjind83_`i'
	ren prdtind1_`i' dtind94_`i'
	ren prmjocc1_`i' mjocc83_`i'
	ren prdtocc1_`i' dtocc83_`i'
	replace   mjind83_`i'=. if mjind83_`i'<1
	replace   mjocc83_`i'=. if mjocc83_`i'<1
	replace   dtind94_`i'=. if dtind94_`i'<1
	replace   dtocc83_`i'=. if dtocc83_`i'<1
}
else if ${x${t_`i'}}>=200301 {
	ren peio1icd_`i' ind03_`i'
	ren peio1ocd_`i' occ03_`i'
	replace ind03_`i'=.   if ind03_`i'<1
	replace occ03_`i'=.   if occ03_`i'<1
	gen mjocc83_`i'=.
	gen dtocc83_`i'=.
	gen occ92_`i'=.
	ren prmjind1_`i' mjind03_`i'
	ren prdtind1_`i' dtind03_`i'
	ren prmjocc1_`i' mjocc03_`i'
	ren prdtocc1_`i' dtocc03_`i'
	replace mjind03_`i'=. if mjind03_`i'<1
	replace dtind03_`i'=. if dtind03_`i'<1
	replace mjocc03_`i'=. if mjocc03_`i'<1
	replace dtocc03_`i'=. if dtocc03_`i'<1
}


* generate consistent occupation variable occ92r, coded as occ92, from 1983 onwards:

if ${x${t_`i'}}>=198301 & ${x${t_`i'}}<=199112 { 
	gen int occ92r_`i'=occ80_`i'
	replace occ92r_`i'=18  if occ80_`i'==16
	replace occ92r_`i'=19  if occ80_`i'==18
	replace occ92r_`i'=22  if occ80_`i'==19
	replace occ92r_`i'=19  if occ80_`i'==18
	replace occ92r_`i'=178 if occ80_`i'==179
	replace occ92r_`i'=461 if occ80_`i'==463
	replace occ92r_`i'=462 if occ80_`i'==464
	replace occ92r_`i'=occ80_`i'-2 if occ80_`i'>=463 & occ80_`i'>=468
}
else if ${x${t_`i'}}>=199201 & ${x${t_`i'}}<=200212  {
	gen int occ92r_`i'=occ92_`i'
}
else if ${x${t_`i'}}>=200301 {
	* INCOMPLETE !!!!!!!
}


* generate consistent industry variable ind92r, coded as ind92, from 1983 onwards:
if ${x${t_`i'}}>=198301 & ${x${t_`i'}}<=199112 {
	gen int ind92r_`i'=ind80_`i'
	replace ind92r_`i'=30  if ind80_`i'==20
	replace ind92r_`i'=20  if ind80_`i'==21
	replace ind92r_`i'=31  if ind80_`i'==30
	replace ind92r_`i'=32  if ind80_`i'==31
	replace ind92r_`i'=450 if ind80_`i'==460
	replace ind92r_`i'=451 if ind80_`i'==461
	replace ind92r_`i'=452 if ind80_`i'==462
	replace ind92r_`i'=623 if ind80_`i'==630
	replace ind92r_`i'=630 if ind80_`i'==631
	replace ind92r_`i'=631 if ind80_`i'==632
	replace ind92r_`i'=632 if ind80_`i'==640
	replace ind92r_`i'=631 if ind80_`i'==632
	replace ind92r_`i'=662 if ind80_`i'==661
	replace ind92r_`i'=663 if ind80_`i'==662
	replace ind92r_`i'=741 if ind80_`i'==732
	replace ind92r_`i'=732 if ind80_`i'==740
	replace ind92r_`i'=740 if ind80_`i'==741
	replace ind92r_`i'=741 if ind80_`i'==742
	replace ind92r_`i'=742 if ind80_`i'==750
	replace ind92r_`i'=802 if ind80_`i'==801
	replace ind92r_`i'=810 if ind80_`i'==802
	replace ind92r_`i'=893 if ind80_`i'==892
}
else if ${x${t_`i'}}>=199201 & ${x${t_`i'}}<=199312  {
	gen int ind92r_`i' = ind92_`i'
}
else if ${x${t_`i'}}>=199401 & ${x${t_`i'}}<=200212 {
	gen int    ind92r_`i'=ind92_`i'
	gen dtind94r_`i'=dtind94_`i'
}
else if ${x${t_`i'}}>=200301 {
	gen int ind92r_`i'=.

replace ind92r_`i'= 10    if ind03_`i'==    170
replace ind92r_`i'= 11    if ind03_`i'==    180
replace ind92r_`i'= 31    if ind03_`i'==    190
replace ind92r_`i'= 230   if ind03_`i'==    270
replace ind92r_`i'= 32    if ind03_`i'==    280
replace ind92r_`i'= 30    if ind03_`i'==    290

replace ind92r_`i'= 42    if ind03_`i'==    370
replace ind92r_`i'= 41    if ind03_`i'==    380
replace ind92r_`i'= 40    if ind03_`i'==    390
replace ind92r_`i'= 50    if ind03_`i'==    470
replace ind92r_`i'= 50    if ind03_`i'==    480
replace ind92r_`i'= 42    if ind03_`i'==    490

replace ind92r_`i'= 60    if ind03_`i'==    770

replace ind92r_`i'= 261   if ind03_`i'==    2470
replace ind92r_`i'= 262   if ind03_`i'==    2480
replace ind92r_`i'= 250   if ind03_`i'==    2490
replace ind92r_`i'= 251   if ind03_`i'==    2570
replace ind92r_`i'= 262   if ind03_`i'==    2590
replace ind92r_`i'= 270   if ind03_`i'==    2670
replace ind92r_`i'= 272   if ind03_`i'==    2680
replace ind92r_`i'= 280   if ind03_`i'==    2690
replace ind92r_`i'= 271   if ind03_`i'==    2770
replace ind92r_`i'= 291   if ind03_`i'==    2780
replace ind92r_`i'= 281   if ind03_`i'==    2790
replace ind92r_`i'= 282   if ind03_`i'==    2870
replace ind92r_`i'= 290   if ind03_`i'==    2880
replace ind92r_`i'= 300   if ind03_`i'==    2890
replace ind92r_`i'= 292   if ind03_`i'==    2970
replace ind92r_`i'= 300   if ind03_`i'==    2980
replace ind92r_`i'= 301   if ind03_`i'==    2990
replace ind92r_`i'= 311   if ind03_`i'==    3070
replace ind92r_`i'= 312   if ind03_`i'==    3080
replace ind92r_`i'= 321   if ind03_`i'==    3090
replace ind92r_`i'= 320   if ind03_`i'==    3170
replace ind92r_`i'= 310   if ind03_`i'==    3180
replace ind92r_`i'= 331   if ind03_`i'==    3190
replace ind92r_`i'= 332   if ind03_`i'==    3290
replace ind92r_`i'= 322   if ind03_`i'==    3360
replace ind92r_`i'= 341   if ind03_`i'==    3370
replace ind92r_`i'= 371   if ind03_`i'==    3380
replace ind92r_`i'= 342   if ind03_`i'==    3390
replace ind92r_`i'= 340   if ind03_`i'==    3470
replace ind92r_`i'= 342   if ind03_`i'==    3490
replace ind92r_`i'= 351   if ind03_`i'==    3570
replace ind92r_`i'= 352   if ind03_`i'==    3580
replace ind92r_`i'= 362   if ind03_`i'==    3590
replace ind92r_`i'= 361   if ind03_`i'==    3670
replace ind92r_`i'= 360   if ind03_`i'==    3680
replace ind92r_`i'= 370   if ind03_`i'==    3690
replace ind92r_`i'= 241   if ind03_`i'==    3770
replace ind92r_`i'= 231   if ind03_`i'==    3780
replace ind92r_`i'= 232   if ind03_`i'==    3790
replace ind92r_`i'= 241   if ind03_`i'==    3870

replace ind92r_`i'= 242   if ind03_`i'==    3890
replace ind92r_`i'= 372   if ind03_`i'==    3960
replace ind92r_`i'= 390   if ind03_`i'==    3970
replace ind92r_`i'= 391   if ind03_`i'==    3980
replace ind92r_`i'= 392   if ind03_`i'==    3990

replace ind92r_`i'= 110   if ind03_`i'==    1070
replace ind92r_`i'= 112   if ind03_`i'==    1080
replace ind92r_`i'= 102   if ind03_`i'==    1090
replace ind92r_`i'= 101   if ind03_`i'==    1170
replace ind92r_`i'= 100   if ind03_`i'==    1180
replace ind92r_`i'= 610   if ind03_`i'==    1190
replace ind92r_`i'= 111   if ind03_`i'==    1270
replace ind92r_`i'= 121   if ind03_`i'==    1280
replace ind92r_`i'= 122   if ind03_`i'==    1290
replace ind92r_`i'= 120   if ind03_`i'==    1370
replace ind92r_`i'= 130   if ind03_`i'==    1390
replace ind92r_`i'= 142   if ind03_`i'==    1470
replace ind92r_`i'= 151   if ind03_`i'==    1480
replace ind92r_`i'= 140   if ind03_`i'==    1490
replace ind92r_`i'= 141   if ind03_`i'==    1570
replace ind92r_`i'= 150   if ind03_`i'==    1590
replace ind92r_`i'= 225   if ind03_`i'==    1670
replace ind92r_`i'= 151   if ind03_`i'==    1680
replace ind92r_`i'= 152   if ind03_`i'==    1690
replace ind92r_`i'= 221   if ind03_`i'==    1770
replace ind92r_`i'= 220   if ind03_`i'==    1790
replace ind92r_`i'= 160   if ind03_`i'==    1870
replace ind92r_`i'= 162   if ind03_`i'==    1880
replace ind92r_`i'= 161   if ind03_`i'==    1890
replace ind92r_`i'= 172   if ind03_`i'==    1990
replace ind92r_`i'= 200   if ind03_`i'==    2070
replace ind92r_`i'= 201   if ind03_`i'==    2090
replace ind92r_`i'= 180   if ind03_`i'==    2170
replace ind92r_`i'= 191   if ind03_`i'==    2180
replace ind92r_`i'= 181   if ind03_`i'==    2190
replace ind92r_`i'= 190   if ind03_`i'==    2270
replace ind92r_`i'= 182   if ind03_`i'==    2280
replace ind92r_`i'= 192   if ind03_`i'==    2290
replace ind92r_`i'= 212   if ind03_`i'==    2370
replace ind92r_`i'= 210   if ind03_`i'==    2380
replace ind92r_`i'= 211   if ind03_`i'==    2390

replace ind92r_`i'= 500   if ind03_`i'==    4070
replace ind92r_`i'= 501   if ind03_`i'==    4080
replace ind92r_`i'= 502   if ind03_`i'==    4090
replace ind92r_`i'= 510   if ind03_`i'==    4170
replace ind92r_`i'= 511   if ind03_`i'==    4180

replace ind92r_`i'= 512   if ind03_`i'==    4190
replace ind92r_`i'= 521   if ind03_`i'==    4260
replace ind92r_`i'= 530   if ind03_`i'==    4270
replace ind92r_`i'= 531   if ind03_`i'==    4280
replace ind92r_`i'= 532   if ind03_`i'==    4290
replace ind92r_`i'= 540   if ind03_`i'==    4370
replace ind92r_`i'= 541   if ind03_`i'==    4380
replace ind92r_`i'= 542   if ind03_`i'==    4390
replace ind92r_`i'= 550   if ind03_`i'==    4470
replace ind92r_`i'= 551   if ind03_`i'==    4480
replace ind92r_`i'= 552   if ind03_`i'==    4490
replace ind92r_`i'= 560   if ind03_`i'==    4560
replace ind92r_`i'= 561   if ind03_`i'==    4570
replace ind92r_`i'= 562   if ind03_`i'==    4580
replace ind92r_`i'= 571   if ind03_`i'==    4585
replace ind92r_`i'= 571   if ind03_`i'==    4590


replace ind92r_`i'= 612   if ind03_`i'==    4670
replace ind92r_`i'= 622   if ind03_`i'==    4680
replace ind92r_`i'= 622   if ind03_`i'==    4690
replace ind92r_`i'= 631   if ind03_`i'==    4770
replace ind92r_`i'= 632   if ind03_`i'==    4780
replace ind92r_`i'= 633   if ind03_`i'==    4790
replace ind92r_`i'= 580   if ind03_`i'==    4870
replace ind92r_`i'= 581   if ind03_`i'==    4880
replace ind92r_`i'= 582   if ind03_`i'==    4890
replace ind92r_`i'= 601   if ind03_`i'==    4970
replace ind92r_`i'= 602   if ind03_`i'==    4980
replace ind92r_`i'= 650   if ind03_`i'==    4990
replace ind92r_`i'= 650   if ind03_`i'==    5070
replace ind92r_`i'= 642   if ind03_`i'==    5080
replace ind92r_`i'= 621   if ind03_`i'==    5090
replace ind92r_`i'= 623   if ind03_`i'==    5170
replace ind92r_`i'= 630   if ind03_`i'==    5180

replace ind92r_`i'= 660   if ind03_`i'==    5190
replace ind92r_`i'= 651   if ind03_`i'==    5270
replace ind92r_`i'= 662   if ind03_`i'==    5280
replace ind92r_`i'= 640   if ind03_`i'==    5290
replace ind92r_`i'= 652   if ind03_`i'==    5370
replace ind92r_`i'= 591   if ind03_`i'==    5380
replace ind92r_`i'= 600   if ind03_`i'==    5390
replace ind92r_`i'= 681   if ind03_`i'==    5470
replace ind92r_`i'= 652   if ind03_`i'==    5480
replace ind92r_`i'= 682   if ind03_`i'==    5490
replace ind92r_`i'= 661   if ind03_`i'==    5570
replace ind92r_`i'= 682   if ind03_`i'==    5580
replace ind92r_`i'= 663   if ind03_`i'==    5590
replace ind92r_`i'= 663   if ind03_`i'==    5591
replace ind92r_`i'= 663   if ind03_`i'==    5592
replace ind92r_`i'= 670   if ind03_`i'==    5670
replace ind92r_`i'= 672   if ind03_`i'==    5680
replace ind92r_`i'= 671   if ind03_`i'==    5690
replace ind92r_`i'= 691   if ind03_`i'==    5790

replace ind92r_`i'= 421   if ind03_`i'==    6070
replace ind92r_`i'= 400   if ind03_`i'==    6080
replace ind92r_`i'= 420   if ind03_`i'==    6090
replace ind92r_`i'= 410   if ind03_`i'==    6170
replace ind92r_`i'= 401   if ind03_`i'==    6180
replace ind92r_`i'= 402   if ind03_`i'==    6190
replace ind92r_`i'= 422   if ind03_`i'==    6270
replace ind92r_`i'= 810   if ind03_`i'==    6280
replace ind92r_`i'= 432   if ind03_`i'==    6290
replace ind92r_`i'= 412   if ind03_`i'==    6370
replace ind92r_`i'= 410   if ind03_`i'==    6380
replace ind92r_`i'= 411   if ind03_`i'==    6390

replace ind92r_`i'= 450   if ind03_`i'==    570
replace ind92r_`i'= 451   if ind03_`i'==    580
replace ind92r_`i'= 452   if ind03_`i'==    590
replace ind92r_`i'= 470   if ind03_`i'==    670
replace ind92r_`i'= 471   if ind03_`i'==    680
replace ind92r_`i'= 472   if ind03_`i'==    690


replace ind92r_`i'= 171   if ind03_`i'==    6470
replace ind92r_`i'= 172   if ind03_`i'==    6480
replace ind92r_`i'= 732   if ind03_`i'==    6490
replace ind92r_`i'= 800   if ind03_`i'==    6570
replace ind92r_`i'= 341   if ind03_`i'==    6590
replace ind92r_`i'= 341   if ind03_`i'==    6670
replace ind92r_`i'= 172   if ind03_`i'==    6675
replace ind92r_`i'= 482   if ind03_`i'==    6680
replace ind92r_`i'= 440   if ind03_`i'==    6690
            
replace ind92r_`i'= 441   if ind03_`i'==    6692
replace ind92r_`i'= 852   if ind03_`i'==    6695
replace ind92r_`i'= 852   if ind03_`i'==    6770
replace ind92r_`i'= 852   if ind03_`i'==    6780

replace ind92r_`i'= 700   if ind03_`i'==    6870
replace ind92r_`i'= 701   if ind03_`i'==    6880
replace ind92r_`i'= 702   if ind03_`i'==    6890
replace ind92r_`i'= 710   if ind03_`i'==    6970
replace ind92r_`i'= 711   if ind03_`i'==    6990

replace ind92r_`i'= 712   if ind03_`i'==    7070
replace ind92r_`i'= 742   if ind03_`i'==    7080
replace ind92r_`i'= 801   if ind03_`i'==    7170
replace ind92r_`i'= 741   if ind03_`i'==    7180
replace ind92r_`i'= 741   if ind03_`i'==    7190
            
replace ind92r_`i'= 841   if ind03_`i'==    7270
replace ind92r_`i'= 890   if ind03_`i'==    7280
replace ind92r_`i'= 882   if ind03_`i'==    7290
replace ind92r_`i'= 741   if ind03_`i'==    7370
replace ind92r_`i'= 732   if ind03_`i'==    7380
replace ind92r_`i'= 892   if ind03_`i'==    7390
replace ind92r_`i'= 891   if ind03_`i'==    7460
replace ind92r_`i'= 721   if ind03_`i'==    7470
replace ind92r_`i'= 12    if ind03_`i'==    7480
replace ind92r_`i'= 891   if ind03_`i'==    7490

replace ind92r_`i'= 710   if ind03_`i'==    7570
replace ind92r_`i'= 741   if ind03_`i'==    7580
replace ind92r_`i'= 741   if ind03_`i'==    7590
replace ind92r_`i'= 432   if ind03_`i'==    7670
replace ind92r_`i'= 740   if ind03_`i'==    7680
replace ind92r_`i'= 722   if ind03_`i'==    7690
replace ind92r_`i'= 20    if ind03_`i'==    7770
replace ind92r_`i'= 741   if ind03_`i'==    7780
replace ind92r_`i'= 471   if ind03_`i'==    7790
replace ind92r_`i'= 842   if ind03_`i'==    7860
replace ind92r_`i'= 850   if ind03_`i'==    7870
replace ind92r_`i'= 851   if ind03_`i'==    7880
replace ind92r_`i'= 860   if ind03_`i'==    7890

replace ind92r_`i'= 812   if ind03_`i'==    7970
replace ind92r_`i'= 820   if ind03_`i'==    7980
replace ind92r_`i'= 821   if ind03_`i'==    7990
replace ind92r_`i'= 822   if ind03_`i'==    8070
replace ind92r_`i'= 830   if ind03_`i'==    8080
replace ind92r_`i'= 840   if ind03_`i'==    8090
replace ind92r_`i'= 840   if ind03_`i'==    8170
replace ind92r_`i'= 840   if ind03_`i'==    8180
replace ind92r_`i'= 832   if ind03_`i'==    8270
replace ind92r_`i'= 870   if ind03_`i'==    8290
replace ind92r_`i'= 831   if ind03_`i'==    8190
replace ind92r_`i'= 863   if ind03_`i'==    8370
replace ind92r_`i'= 871   if ind03_`i'==    8380
replace ind92r_`i'= 861   if ind03_`i'==    8390
replace ind92r_`i'= 862   if ind03_`i'==    8470

replace ind92r_`i'= 810   if ind03_`i'==    8560
replace ind92r_`i'= 872   if ind03_`i'==    8570
replace ind92r_`i'= 802   if ind03_`i'==    8580
replace ind92r_`i'= 810   if ind03_`i'==    8590
            
replace ind92r_`i'= 762   if ind03_`i'==    8660
replace ind92r_`i'= 770   if ind03_`i'==    8670
replace ind92r_`i'= 641   if ind03_`i'==    8680
replace ind92r_`i'= 641   if ind03_`i'==    8690

replace ind92r_`i'= 751   if ind03_`i'==    8770
replace ind92r_`i'= 750   if ind03_`i'==    8780
replace ind92r_`i'= 752   if ind03_`i'==    8790
replace ind92r_`i'= 760   if ind03_`i'==    8870
replace ind92r_`i'= 752   if ind03_`i'==    8880

replace ind92r_`i'= 782   if ind03_`i'==    8890
replace ind92r_`i'= 780   if ind03_`i'==    8970
replace ind92r_`i'= 772   if ind03_`i'==    8980
replace ind92r_`i'= 791   if ind03_`i'==    8990
replace ind92r_`i'= 771   if ind03_`i'==    9070
replace ind92r_`i'= 781   if ind03_`i'==    9080
replace ind92r_`i'= 791   if ind03_`i'==    9090

replace ind92r_`i'= 880   if ind03_`i'==    9160
replace ind92r_`i'= 881   if ind03_`i'==    9170
replace ind92r_`i'= 873   if ind03_`i'==    9180
replace ind92r_`i'= 881   if ind03_`i'==    9190
replace ind92r_`i'= 761   if ind03_`i'==    9290

replace ind92r_`i'= 900   if ind03_`i'==    9370
replace ind92r_`i'= 921   if ind03_`i'==    9380
replace ind92r_`i'= 901   if ind03_`i'==    9390
replace ind92r_`i'= 910   if ind03_`i'==    9470
replace ind92r_`i'= 922   if ind03_`i'==    9480
replace ind92r_`i'= 930   if ind03_`i'==    9490
replace ind92r_`i'= 931   if ind03_`i'==    9570
replace ind92r_`i'= 932   if ind03_`i'==    9590
replace ind92r_`i'= 932   if ind03_`i'==    9890
}


* generate consistent NBER industry recode, ind_nber_r:
gen byte ind_nber_r_`i'=.
if ${x${t_`i'}}>=198301 {  /* when available, use our own industry recode ind92r */

replace ind_nber_r_`i'=  1      if ind92r_`i'>=  12     & ind92r_`i'<=   30
replace ind_nber_r_`i'=  2      if ind92r_`i'>=  10     & ind92r_`i'<=   11
replace ind_nber_r_`i'=  3      if ind92r_`i'>=  40     & ind92r_`i'<=   50
replace ind_nber_r_`i'=  4      if ind92r_`i'==  60      
replace ind_nber_r_`i'=  5      if ind92r_`i'>=  230    & ind92r_`i'<=   241
replace ind_nber_r_`i'=  6      if ind92r_`i'==  242     
replace ind_nber_r_`i'=  7      if ind92r_`i'>=  250    & ind92r_`i'<=   262
replace ind_nber_r_`i'=  8      if ind92r_`i'>=  270    & ind92r_`i'<=   280
replace ind_nber_r_`i'=  9      if ind92r_`i'>=  281    & ind92r_`i'<=   300
replace ind_nber_r_`i'=  10     if ind92r_`i'==  301     
replace ind_nber_r_`i'=  11     if ind92r_`i'>=  310    & ind92r_`i'<=   332
replace ind_nber_r_`i'=  12     if ind92r_`i'>=  340    & ind92r_`i'<=   350
replace ind_nber_r_`i'=  13     if ind92r_`i'==  351     
replace ind_nber_r_`i'=  14     if ind92r_`i'==  352     
replace ind_nber_r_`i'=  15     if ind92r_`i'>=  360    & ind92r_`i'<=   370
replace ind_nber_r_`i'=  16     if ind92r_`i'>=  371    & ind92r_`i'<=   382
replace ind_nber_r_`i'=  17     if ind92r_`i'==  390     
replace ind_nber_r_`i'=  18     if ind92r_`i'>=  391    & ind92r_`i'<=   392

replace ind_nber_r_`i'=  19     if ind92r_`i'>=  100    & ind92r_`i'<=   122
replace ind_nber_r_`i'=  20     if ind92r_`i'==  130     
replace ind_nber_r_`i'=  21     if ind92r_`i'>=  132    & ind92r_`i'<=   150
replace ind_nber_r_`i'=  22     if ind92r_`i'>=  151    & ind92r_`i'<=   152
replace ind_nber_r_`i'=  23     if ind92r_`i'>=  160    & ind92r_`i'<=   162
replace ind_nber_r_`i'=  24     if ind92r_`i'>=  171    & ind92r_`i'<=   172
replace ind_nber_r_`i'=  25     if ind92r_`i'>=  180    & ind92r_`i'<=   192
replace ind_nber_r_`i'=  26     if ind92r_`i'>=  200    & ind92r_`i'<=   201
replace ind_nber_r_`i'=  27     if ind92r_`i'>=  210    & ind92r_`i'<=   212
replace ind_nber_r_`i'=  28     if ind92r_`i'>=  220    & ind92r_`i'<=   222
replace ind_nber_r_`i'=  29     if ind92r_`i'>=  400    & ind92r_`i'<=   432
replace ind_nber_r_`i'=  30     if ind92r_`i'>=  440    & ind92r_`i'<=   442
replace ind_nber_r_`i'=  31     if ind92r_`i'>=  450    & ind92r_`i'<=   472
replace ind_nber_r_`i'=  32     if ind92r_`i'>=  500    & ind92r_`i'<=   571
replace ind_nber_r_`i'=  33     if ind92r_`i'>=  580    & ind92r_`i'<=   691
replace ind_nber_r_`i'=  34     if ind92r_`i'>=  700    & ind92r_`i'<=   710
replace ind_nber_r_`i'=  35     if ind92r_`i'>=  711    & ind92r_`i'<=   712

replace ind_nber_r_`i'=  36     if ind92r_`i'==  761     
replace ind_nber_r_`i'=  37     if ind92r_`i'>=  721    & ind92r_`i'<=   750
replace ind_nber_r_`i'=  38     if ind92r_`i'>=  751    & ind92r_`i'<=   760
replace ind_nber_r_`i'=  39     if ind92r_`i'>=  762    & ind92r_`i'<=   791
replace ind_nber_r_`i'=  40     if ind92r_`i'>=  800    & ind92r_`i'<=   810
replace ind_nber_r_`i'=  41     if ind92r_`i'==  831     
replace ind_nber_r_`i'=  42     if ind92r_`i'>=  812    & ind92r_`i'<=   830
replace ind_nber_r_`i'=  42     if ind92r_`i'>=  832    & ind92r_`i'<=   840
replace ind_nber_r_`i'=  43     if ind92r_`i'>=  842    & ind92r_`i'<=   860
replace ind_nber_r_`i'=  44     if ind92r_`i'>=  861    & ind92r_`i'<=   871
replace ind_nber_r_`i'=  45     if ind92r_`i'==  841     
replace ind_nber_r_`i'=  45     if ind92r_`i'>=  872    & ind92r_`i'<=   893
replace ind_nber_r_`i'=  46     if ind92r_`i'>=  31     & ind92r_`i'<=   32
replace ind_nber_r_`i'=  51     if ind92r_`i'==  991     
replace ind_nber_r_`i'=  52     if ind92r_`i'>=  900    & ind92r_`i'<=   932
}
else if ${x${t_`i'}}>=197810 & ${x${t_`i'}}<=198212 {   /* prior to 1983, use ind70 */
replace ind_nber_r_`i'= 1      if ind70_`i'>=   18     & ind70_`i'<=    19
replace ind_nber_r_`i'= 2      if ind70_`i'==   17      
replace ind_nber_r_`i'= 3      if ind70_`i'>=   47     & ind70_`i'<=    57
replace ind_nber_r_`i'= 4      if ind70_`i'>=   67     & ind70_`i'<=    77
replace ind_nber_r_`i'= 5      if ind70_`i'>=   107    & ind70_`i'<=    109
replace ind_nber_r_`i'= 6      if ind70_`i'==   118     
replace ind_nber_r_`i'= 7      if ind70_`i'>=   119    & ind70_`i'<=    138
replace ind_nber_r_`i'= 8      if ind70_`i'>=   139    & ind70_`i'<=    149
replace ind_nber_r_`i'= 9      if ind70_`i'>=   157    & ind70_`i'<=    168
replace ind_nber_r_`i'= 9      if ind70_`i'==   258     
replace ind_nber_r_`i'= 10     if ind70_`i'==   169     
replace ind_nber_r_`i'= 11     if ind70_`i'>=   177    & ind70_`i'<=    198
replace ind_nber_r_`i'= 12     if ind70_`i'>=   199    & ind70_`i'<=    209
replace ind_nber_r_`i'= 13     if ind70_`i'==   219     
replace ind_nber_r_`i'= 14     if ind70_`i'==   227     
replace ind_nber_r_`i'= 15     if ind70_`i'>=   228    & ind70_`i'<=    238
replace ind_nber_r_`i'= 16     if ind70_`i'>=   239    & ind70_`i'<=    257
replace ind_nber_r_`i'= 18     if ind70_`i'==   259     
replace ind_nber_r_`i'= 19     if ind70_`i'>=   268    & ind70_`i'<=    298
replace ind_nber_r_`i'= 20     if ind70_`i'==   299     
replace ind_nber_r_`i'= 21     if ind70_`i'>=   307    & ind70_`i'<=    318
replace ind_nber_r_`i'= 22     if ind70_`i'>=   319    & ind70_`i'<=    327
replace ind_nber_r_`i'= 23     if ind70_`i'>=   328    & ind70_`i'<=    337
replace ind_nber_r_`i'= 24     if ind70_`i'>=   338    & ind70_`i'<=    339
replace ind_nber_r_`i'= 25     if ind70_`i'>=   347    & ind70_`i'<=    369
replace ind_nber_r_`i'= 26     if ind70_`i'>=   377    & ind70_`i'<=    378
replace ind_nber_r_`i'= 27     if ind70_`i'>=   379    & ind70_`i'<=    387
replace ind_nber_r_`i'= 28     if ind70_`i'>=   388    & ind70_`i'<=    398
replace ind_nber_r_`i'= 29     if ind70_`i'>=   407    & ind70_`i'<=    429
replace ind_nber_r_`i'= 30     if ind70_`i'>=   447    & ind70_`i'<=    449
replace ind_nber_r_`i'= 31     if ind70_`i'>=   467    & ind70_`i'<=    479
replace ind_nber_r_`i'= 32     if ind70_`i'>=   507    & ind70_`i'<=    588
replace ind_nber_r_`i'= 33     if ind70_`i'>=   607    & ind70_`i'<=    698
replace ind_nber_r_`i'= 34     if ind70_`i'>=   707    & ind70_`i'<=    709
replace ind_nber_r_`i'= 35     if ind70_`i'>=   717    & ind70_`i'<=    718
replace ind_nber_r_`i'= 36     if ind70_`i'==   769     
replace ind_nber_r_`i'= 37     if ind70_`i'>=   727    & ind70_`i'<=    748
replace ind_nber_r_`i'= 38     if ind70_`i'>=   749    & ind70_`i'<=    759
replace ind_nber_r_`i'= 39     if ind70_`i'>=   777    & ind70_`i'<=    798
replace ind_nber_r_`i'= 40     if ind70_`i'>=   807    & ind70_`i'<=    809
replace ind_nber_r_`i'= 41     if ind70_`i'==   838     
replace ind_nber_r_`i'= 42     if ind70_`i'>=   828    & ind70_`i'<=    837
replace ind_nber_r_`i'= 42     if ind70_`i'>=   839    & ind70_`i'<=    848
replace ind_nber_r_`i'= 43     if ind70_`i'>=   857    & ind70_`i'<=    868
replace ind_nber_r_`i'= 44     if ind70_`i'>=   877    & ind70_`i'<=    897
replace ind_nber_r_`i'= 45     if ind70_`i'>=   887    & ind70_`i'<=    897
replace ind_nber_r_`i'= 45     if ind70_`i'==   849    | ind70_`i'==    869
replace ind_nber_r_`i'= 46     if ind70_`i'>=   27     & ind70_`i'<=    28
replace ind_nber_r_`i'= 52     if ind70_`i'>=   907    & ind70_`i'<=    937
}

}	/* end loop over 4 interviews */

* Generate consistent industry codes, NAICS based (for productivity data):
gen long ind_naicps4=.
gen long ind_naicps3=.
if ${x${t_4}} >= 198301 & ${x${t_4}} <= 200212 { /* ${x${t_4}} >= 198701 & */
	do ind_recode_8702
}
else if ${x${t_4}} >= 200301 & ${x${t_4}} <= 200512 {
	do ind_recode_0305
}


***********************************************************************************************************
* SAMPLE SELECTION CRITERIA BASED ON INDUSTRY/OCCUPATION

* dummy for agriculture
gen ind_agric=0
replace ind_agric=1 if ind_nber_r_4==1 | ind_nber_r_4==2

* generate dummies for nonsupervisory and managerial workers
gen occ_nonsuperv = 1
gen occ_nonmanag = 1

if ${x${t_4}}>=197901 & ${x${t_4}}<=198212  {
	replace occ_nonmanag=.  if occ70_4==.
	replace occ_nonmanag = 0 if (occ70_4 >=201 & occ70_4 <= 246) | occ70_4 == 802
}
else if ${x${t_4}}>=198301 & ${x${t_4}}<=200212  {

	if ${x${t_4}}>=198301 & ${x${t_4}}<=199112  {
    		gen int occ8090=occ80_4
    	}
	else if ${x${t_4}}>=199201 & ${x${t_4}}<=200212  {
    		gen int occ8090=occ92_4
    	}
	qui replace occ_nonsuperv = . if occ8090 == .
	qui replace occ_nonsuperv = 0 if  ( (occ8090 >=   0 & occ8090 <= 39)  /*
                                */	    |  occ8090 == 243                   /*
                                */	    | (occ8090 >= 300 & occ8090 <= 307) /*
                                */	    | (occ8090 >= 413 & occ8090 <= 415) /*
                                */      |  occ8090 == 433 | occ8090 == 448 | occ8090 == 456 /*
                                */	    | (occ8090 >=473  & occ8090 <= 476) /*
                                */      |  occ8090 == 477 | occ8090 == 485 | occ8090 == 494 /*
                                */	    |  occ8090 == 503                   /*
                                */	    | (occ8090 >= 550 & occ8090 <= 558) /* 
                                */	    |  occ8090 == 613 | occ8090 == 628 | occ8090 == 633 /*
                                */	    |  occ8090 == 803 | occ8090 == 843 | occ8090 == 863 | occ8090 == 864 )

	qui replace occ_nonmanag = . if occ8090 == .
	qui replace occ_nonmanag = 0 if ( (occ8090 >= 0 & occ8090 <= 39) | (occ8090 >= 890 & occ8090 <= 9999) )  
	drop occ8090
}
else if ${x${t_4}}>=200301 {
	qui replace occ_nonsuperv = . if occ03_4 == .
	qui replace occ_nonsuperv = 0 if  (occ03_4 >=   10 & occ03_4 <=  439) /*
                                */    | (occ03_4 >= 3700 & occ03_4 <= 3730) /*
                                */    |  occ03_4 == 4010                    /*
                                */    | (occ03_4 >= 4200 & occ03_4 <= 4210) /*
                                */    | (occ03_4 >= 4300 & occ03_4 <= 4320) /*
                                */    | (occ03_4 >= 4700 & occ03_4 <= 4710) /*
                                */    |  occ03_4 == 5000 | occ03_4 == 6000  /*
                                */    |  occ03_4 == 6200 | occ03_4 == 7000  /*
                                */    |  occ03_4 == 7700 | occ03_4 == 9000

	qui replace occ_nonmanag = . if occ03_4 == . 
	qui replace occ_nonmanag = 0 if occ03_4 >= 10 & occ03_4 <= 439 
}

if ${x${t_4}}<=200512  {
	gen byte occ_nonmanag83_cepr = 1 - manag83_cepr
	gen byte occ_nonmanag03_cepr = 1 - manag03_cepr
}
else  {
	gen ind_nber_cepr = .
	gen ind_2d_cepr = .
	gen byte occ_nonmanag83_cepr = .
	gen byte occ_nonmanag03_cepr = .
}


***********************************************************************************************************
* WAGES AND ALLOCATION FLAGS FROM CEPR

if ${x${t_4}}<=200512  {
	ren blsimph_cepr earnhre_alloc
	ren blsimpw_cepr earnwke_alloc
	ren blsimpt_cepr uhours1_alloc_cepr
	ren hrernhr_cepr uhours_assgn_cepr
	ren hrsimptd_cepr uhours_imptd_cepr
}
else  {
	gen w_ln_ot_cepr = .
	gen rw_cepr = .
	gen earnhre_alloc = .
	gen earnwke_alloc = .
	gen uhours1_alloc_cepr = .
	gen uhours_assgn_cepr = .
	gen uhours_imptd_cepr = .
}

} 		/* END QUIETLY */


***********************************************************************************************************
* KEEP ONLY RELEVANT OBSERVATIONS AND VARIABLES

keep if earnhre>0 | earnwke>0 | earnhre_cepr>0 | earnwke_cepr>0 | uearnwk_cepr>0
*keep if ~cow_selfempl   /* drop self-employed: no wages and very small fraction sample, zero post 1989 */
*keep if lfstat_empl_4   /* drop non-employed: tiny fraction sample, zero post 1989 */

local variables1 = "year year_cepr month month_cepr hetenure age age_cepr gereg state " 	/* DATE, REGION, STATE AND HOUSING TENURE
	*/ +"weight weight_cepr earnwt earnwt_cepr longwt " 		/* WEIGHTS
	*/ +"female female_cepr race race_* hispanic* wbho*_cepr maritl* married* "	/* DEMOGRAPHICS
	*/ +"gradeate gradecpe educat educat_cepr educ_* "		/* EDUCATION */
local variables2 = "lfstat_* samejob_* prunedur_* unemdur "		/* LABOR FORCE STATUS
	*/ +"noagrpws prcivlf* prftlf* cow_* union* "			/* SAMPLE SELECTION CRITERIA
	*/ +"paidhre* earnhre* earnwk* uhours* uearnwk_cepr "		/* HOURS AND EARNINGS
	*/ +"match_* "								/* MATCH VARIABLES
	*/ +"ind_nber* ind_2d_cepr ind_agric occ_* ind_naicps* "	/* INDUSTRY AND OCCUPATION
	*/ +"w_* rw_* "								/* WAGES COMPUTED BY CEPR */

keep `variables1' `variables2'
order `variables1' `variables2'
qui compress

*d `variables1' `variables2'

save "${sav_path}consistent_`yymm'", replace

end		/* END PROGRAM DEFINE */


***********************************************************************************************************
* RUN THE PROGRAM

do define_months
forvalues j=228/558 {
if ${x`j'}>=197901 & ${x`j'}<=200607 {
	make_consistent `j'
}
}

log close
