* This file merges data from the cepr to the matched basic monthly data
* It creates some variables which are used to compare the cepr-variables
* with the variables from the basic monthly files, e.g. a hispanic dummy.
* MS 9/2006, revised TvR 10/2006

version 7.0
set mem 50m
set more off

cap log close
log using prep_mergecps, text replace

global cepr_path "../data_raw_cepr/"            /* CEPR data */
global morg_8711_path = "../data_raw_nber/"	/* NBER MORG data for 1987:11 */
global dat_path "../data_matched/"     		/* Matched basic monthly files */
global sav_path "../data_matched_all/"     	/* Matched basic monthly files merged with CEPR (and NBER) data */

cap program drop merge_cepr
program define merge_cepr

global t_4 "`1'"

* Prepare CEPR data 2004:5 - 2005:7 (hhnum missing):
if ${x${t_4}}>=0405 & ${x${t_4}}<=0507  {
	use "${cepr_path}cepr_small_${x${t_4}}", clear
	sort mis state hhid lineno
	save "${cepr_path}cepr_small_${x${t_4}}", replace
}

* Load the bmd data:
use "${dat_path}m${x${t_4}}", clear

******************************************************************************************
* In 1987:11 some variables (marital status, class of worker) are missing
* from the basic monthly files. We get these variables from the NBER MORG data
if ${x${t_4}}==8711       {
sort  mis state hhid hhnum
merge mis state hhid hhnum using "${morg_8711_path}morg87_small"
tab _merge
drop _merge
}
******************************************************************************************

* dummy for hispanic
gen byte hispanic=0
cap replace hispanic=1 if   origin_4>=1 &   origin_4<=7     /* 1979 - 1988 */
cap replace hispanic=1 if a_reorgn_4>=1 & a_reorgn_4<=7     /* 1989 - 1993 */
cap replace hispanic=1 if prhspnon_4==1                     /* 1994 - 2002 */
cap replace hispanic=1 if pehspnon_4==1                     /* 2003 - 2006 */
cap drop pehspnon_*
cap drop prhspnon_*

* Merge with CEPR data:
if ${t_4}<=551 {
if ${x${t_4}}>=0405 & ${x${t_4}}<=0507  {
	sort  mis state hhid lineno
	merge mis state hhid lineno using "${cepr_path}cepr_small_${x${t_4}}"
}
else {
	sort  mis state hhid hhnum lineno
	merge mis state hhid hhnum lineno using "${cepr_path}cepr_small_${x${t_4}}"
}

* In 1987:11 variable origin is missing in basic monhtly files
if ${x${t_4}}==8711 {
    replace hispanic=1 if wbho_cepr==3
}

count 
global numobs_${x${t_4}}=r(N)
count if _merge==3
global merges_${x${t_4}}=r(N)
global mergerate_${x${t_4}}=${merges_${x${t_4}}}/${numobs_${x${t_4}}}
ren _merge merge_cepr
tab merge_cepr

* STEP 4:  Define merge quality variables
gen byte sex_c=0
replace sex_c=1 if female_cepr==0
replace sex_c=2 if female_cepr==1

gen byte sexdif=sex_4==sex_c

*tab sex_4 sex_c
*tab sexdif

* generate race variable race_b to make it comparable with cepr-data
gen byte race_b=0

if ${t_4}>=228 & ${t_4}<=263 {          /* 7901 until 8112 */
replace race_b=1 if race78_4==1         /* white */
replace race_b=2 if race78_4==2         /* black */
replace race_b=4 if race78_4==3         /* other */
}
if ${t_4}>=264 & ${t_4}<=305 {          /* 8201 until  8506 */
replace race_b=1 if race82_4==1         /* white */
replace race_b=2 if race82_4==2         /* black */
replace race_b=4 if race82_4>2 & race82_4<20  /* other */
}
if ${t_4}>=306 & ${t_4}<=347 {          /* 8507 until 8812 */
replace race_b=1 if race_rcde_4==1      /* white */
replace race_b=2 if race_rcde_4==2      /* black */ 
replace race_b=4 if race_rcde_4==3      /* other */
}
if ${t_4}>=348 & ${t_4}<=431 {          /* 8901 until 9512 */
replace race_b=1 if race82_4==1         /* white */
replace race_b=2 if race82_4==2         /* black */
replace race_b=4 if race82_4>2 & race82_4<20  /* other */
}
if ${t_4}>=432 & ${t_4}<=515 {          /* 9601 until 0212 */
replace race_b=1 if race96_4==1         /* white */
replace race_b=2 if race96_4==2         /* black */
replace race_b=4 if race96_4>2 & race96_4<20  /* other */
}
if ${t_4}>=516 {                        /* 0301 until end */
replace race_b=1 if prdtrace_4==1       /* white */
replace race_b=2 if prdtrace_4==2       /* black */
replace race_b=4 if prdtrace_4>2 & prdtrace_4<20  /* other */
}

replace race_b=3 if hispanic==1

gen byte racedif=race_b==wbho_cepr

gen byte agedif=age_cepr==age_4
*tab agedif

display "Assess merge"

gen byte s_r_a_cepr  =(sexdif==0 | racedif==0 | agedif==0)
*tab s_r_a_cepr

}
save "${sav_path}cepr_merged_${x${t_4}}", replace

end

global  x225    7810
global  x226    7811
global  x227    7812
global  x228    7901
global  x229    7902
global  x230    7903
global  x231    7904
global  x232    7905
global  x233    7906
global  x234    7907
global  x235    7908
global  x236    7909
global  x237    7910
global  x238    7911
global  x239    7912
global  x240    8001
global  x241    8002
global  x242    8003
global  x243    8004
global  x244    8005
global  x245    8006
global  x246    8007
global  x247    8008
global  x248    8009
global  x249    8010
global  x250    8011
global  x251    8012
global  x252    8101
global  x253    8102
global  x254    8103
global  x255    8104
global  x256    8105
global  x257    8106
global  x258    8107
global  x259    8108
global  x260    8109
global  x261    8110
global  x262    8111
global  x263    8112
global  x264    8201
global  x265    8202
global  x266    8203
global  x267    8204
global  x268    8205
global  x269    8206
global  x270    8207
global  x271    8208
global  x272    8209
global  x273    8210
global  x274    8211
global  x275    8212
global  x276    8301
global  x277    8302
global  x278    8303
global  x279    8304
global  x280    8305
global  x281    8306
global  x282    8307
global  x283    8308
global  x284    8309
global  x285    8310
global  x286    8311
global  x287    8312
global  x288    8401
global  x289    8402
global  x290    8403
global  x291    8404
global  x292    8405
global  x293    8406
global  x294    8407
global  x295    8408
global  x296    8409
global  x297    8410
global  x298    8411
global  x299    8412
global  x300    8501
global  x301    8502
global  x302    8503
global  x303    8504
global  x304    8505
global  x305    8506
global  x306    8507
global  x307    8508
global  x308    8509
global  x309    8510
global  x310    8511
global  x311    8512
global  x312    8601
global  x313    8602
global  x314    8603
global  x315    8604
global  x316    8605
global  x317    8606
global  x318    8607
global  x319    8608
global  x320    8609
global  x321    8610
global  x322    8611
global  x323    8612
global  x324    8701
global  x325    8702
global  x326    8703
global  x327    8704
global  x328    8705
global  x329    8706
global  x330    8707
global  x331    8708
global  x332    8709
global  x333    8710
global  x334    8711
global  x335    8712
global  x336    8801
global  x337    8802
global  x338    8803
global  x339    8804
global  x340    8805
global  x341    8806
global  x342    8807
global  x343    8808
global  x344    8809
global  x345    8810
global  x346    8811
global  x347    8812
global  x348    8901
global  x349    8902
global  x350    8903
global  x351    8904
global  x352    8905
global  x353    8906
global  x354    8907
global  x355    8908
global  x356    8909
global  x357    8910
global  x358    8911
global  x359    8912
global  x360    9001
global  x361    9002
global  x362    9003
global  x363    9004
global  x364    9005
global  x365    9006
global  x366    9007
global  x367    9008
global  x368    9009
global  x369    9010
global  x370    9011
global  x371    9012
global  x372    9101
global  x373    9102
global  x374    9103
global  x375    9104
global  x376    9105
global  x377    9106
global  x378    9107
global  x379    9108
global  x380    9109
global  x381    9110
global  x382    9111
global  x383    9112
global  x384    9201
global  x385    9202
global  x386    9203
global  x387    9204
global  x388    9205
global  x389    9206
global  x390    9207
global  x391    9208
global  x392    9209
global  x393    9210
global  x394    9211
global  x395    9212
global  x396    9301
global  x397    9302
global  x398    9303
global  x399    9304
global  x400    9305
global  x401    9306
global  x402    9307
global  x403    9308
global  x404    9309
global  x405    9310
global  x406    9311
global  x407    9312
global  x408    9401
global  x409    9402
global  x410    9403
global  x411    9404
global  x412    9405
global  x413    9406
global  x414    9407
global  x415    9408
global  x416    9409
global  x417    9410
global  x418    9411
global  x419    9412
global  x420    9501
global  x421    9502
global  x422    9503
global  x423    9504
global  x424    9505
global  x425    9506
global  x426    9507
global  x427    9508
global  x428    9509
global  x429    9510
global  x430    9511
global  x431    9512
global  x432    9601
global  x433    9602
global  x434    9603
global  x435    9604
global  x436    9605
global  x437    9606
global  x438    9607
global  x439    9608
global  x440    9609
global  x441    9610
global  x442    9611
global  x443    9612
global  x444    9701
global  x445    9702
global  x446    9703
global  x447    9704
global  x448    9705
global  x449    9706
global  x450    9707
global  x451    9708
global  x452    9709
global  x453    9710
global  x454    9711
global  x455    9712
global  x456    9801
global  x457    9802
global  x458    9803
global  x459    9804
global  x460    9805
global  x461    9806
global  x462    9807
global  x463    9808
global  x464    9809
global  x465    9810
global  x466    9811
global  x467    9812
global  x468    9901
global  x469    9902
global  x470    9903
global  x471    9904
global  x472    9905
global  x473    9906
global  x474    9907
global  x475    9908
global  x476    9909
global  x477    9910
global  x478    9911
global  x479    9912
global  x480    0001
global  x481    0002
global  x482    0003
global  x483    0004
global  x484    0005
global  x485    0006
global  x486    0007
global  x487    0008
global  x488    0009
global  x489    0010
global  x490    0011
global  x491    0012
global  x492    0101
global  x493    0102
global  x494    0103
global  x495    0104
global  x496    0105
global  x497    0106
global  x498    0107
global  x499    0108
global  x500    0109
global  x501    0110
global  x502    0111
global  x503    0112
global  x504    0201
global  x505    0202
global  x506    0203
global  x507    0204
global  x508    0205
global  x509    0206
global  x510    0207
global  x511    0208
global  x512    0209
global  x513    0210
global  x514    0211
global  x515    0212
global  x516    0301
global  x517    0302
global  x518    0303
global  x519    0304
global  x520    0305
global  x521    0306
global  x522    0307
global  x523    0308
global  x524    0309
global  x525    0310
global  x526    0311
global  x527    0312
global  x528    0401
global  x529    0402
global  x530    0403
global  x531    0404
global  x532    0405
global  x533    0406
global  x534    0407
global  x535    0408
global  x536    0409
global  x537    0410
global  x538    0411
global  x539    0412
global  x540    0501
global  x541    0502
global  x542    0503
global  x543    0504
global  x544    0505
global  x545    0506
global  x546    0507
global  x547    0508
global  x548    0509
global  x549    0510
global  x550    0511
global  x551    0512
global  x552    0601
global  x553    0602
global  x554    0603
global  x555    0604
global  x556    0605
global  x557    0606
global  x557    0606
global  x558    0607


* RUN THE PROGRAM

forvalues i=228/558 {
*forvalues i=528/558 {
	merge_cepr `i'
}
