
* PROGRAM:  mergecps.do
* DATE:  August 22, 2006
* this program merges four consecutive cps surveys (basic monthly data)
* Taken from Madrian and Lefgren, revised MS 9/2006, revised TvR 10/2006

version 7.0
set mem 100m
set more off

cap log close
log using mergecps.log, text replace

global do_path  " "                  /* where auxilliary do-file multobs.do is saved */
global dat_path "../data_raw_dta/"     /* where raw data prepered for merging is saved */
global int_path "../data_matched/"       /* where intermediate data is to be saved */
global sav_path "../data_matched/"       /* where merged data is to be saved */

cap program drop mergecps

program define mergecps

* define macros for merging period
global t_4 "`1'"
global t_3 =  ${t_4}-1
global t_2 =  ${t_3}-1
global t_1 =  ${t_2}-1
display "t_1=${t_1}"
 
* STEP 1:  Load data for individuals in time t_4

display "Reading in t_4 Data"
display "t_4=${t_4}"
use ${dat_path}d_${x${t_4}} if mis==4 | mis==8, clear

* rename t_4-data
renvars, suffix(_4)
gen int period=${t_4}
ren state_4 state
ren hhid_4    hhid
ren hhnum_4   hhnum
ren lineno_4  lineno
ren mis_4     mis

if ${t_4}>=411 & ${t_4}<=430  {
ren hrsersuf_4 hrsersuf
sort mis state hhid hrsersuf hhnum lineno
}
else {
sort mis state hhid hhnum lineno
}

gen obsno2=_n

* Variables for calculation of merge rate:
count
gen int n_obs_4=r(N)
save ${int_path}match${x${t_4}}B, replace

* STEP 2:  Load data for individuals in time t_3
display "Reading in individual data"
use ${dat_path}d_${x${t_3}} if mis==3 | mis==7, clear
   
replace mis=mis+1
 
* rename t_3-data
renvars, suffix(_3)
ren state_3 state
ren hhid_3    hhid
ren hhnum_3   hhnum
ren lineno_3  lineno
ren mis_3     mis

* STEP 3:  Merge t_4 data to t_3 data

if ${t_4}>=411 & ${t_4}<=430  {
ren hrsersuf_3 hrsersuf
sort mis state hhid hrsersuf hhnum lineno
}
else {
sort mis state hhid hhnum lineno
}
gen obsno=_n
display "Merging t_3 and t_4 data"
if ${t_4}>=411 & ${t_4}<=430  {
merge mis state hhid hrsersuf hhnum lineno using  ${int_path}match${x${t_4}}B
}
else {
merge mis state hhid hhnum lineno using  ${int_path}match${x${t_4}}B
}

display "Merge table t_3=${x${t_3}} a"
tab _merge

* STEP 4:  Define merge quality variables

gen byte sexdif=sex_3==sex_4
tab sexdif
replace sexdif=0 if sex_3==.

if ${t_4}>=228 & ${t_4}<=263 {          /* 7901 until 8112 */
gen byte racedif=race78_3==race78_4
replace racedif=0 if race78_3==.
}
if ${t_4}==264 {                        /* 8201 */
gen byte racedif=race_rcde_3==race_rcde_4
replace racedif=0 if race_rcde_3==.
}
if ${t_4}>=265 & ${t_4}<=305 {          /* 8202 until  8506 */
gen byte racedif=race82_3==race82_4 
replace racedif=0 if race82_3==.
}
if ${t_4}>=306 & ${t_4}<=347 {          /* 8507 until 8812 */
gen byte racedif=race_rcde_3==race_rcde_4
replace racedif=0 if race_rcde_3==.
}
if ${t_4}==348 {                        /* 8901 */
gen byte racedif=race_rcde_3==race82_4
replace racedif=1 if race_rcde==3 & (race82_4==4 | race82_4==5)
replace racedif=0 if race_rcde_3==.
}
if ${t_4}>=349 & ${t_4}<=431 {          /* 8902 until 9512 */
gen byte racedif=race82_3==race82_4
replace racedif=0 if race82_3==.
}
if ${t_4}==432 {                        /* 9601 */
gen byte racedif=race82_3==race96_4
replace racedif=1 if race82_3==5
replace racedif=0 if race82_3==.
}
if ${t_4}>=433 & ${t_4}<=515 {          /* 9602 until 0212 */
gen byte racedif=race96_3==race96_4
replace racedif=0 if race96_3==.
}
if ${t_4}==516 {                        /* 0301 */
gen byte racedif=race96_3==prdtrace_4
      replace racedif=1 if prdtrace_4==14 & race96_3==4
      replace racedif=1 if prdtrace_4==6  & race96_3==1
      replace racedif=1 if prdtrace_4==7  & race96_3==1
      replace racedif=1 if prdtrace_4==8  & race96_3==1
      replace racedif=1 if prdtrace_4==9  & race96_3==1
      replace racedif=1 if prdtrace_4==6  & race96_3==2
      replace racedif=1 if prdtrace_4==10 & race96_3==2
      replace racedif=1 if prdtrace_4==11 & race96_3==2
      replace racedif=1 if prdtrace_4==12 & race96_3==2
      replace racedif=1 if prdtrace_4==7  & race96_3==3
      replace racedif=1 if prdtrace_4==10 & race96_3==3
      replace racedif=1 if prdtrace_4==13 & race96_3==3
      replace racedif=1 if prdtrace_4==8  & race96_3==4
      replace racedif=1 if prdtrace_4==9  & race96_3==4
      replace racedif=1 if prdtrace_4==11 & race96_3==4
      replace racedif=1 if prdtrace_4==12 & race96_3==4
      replace racedif=1 if prdtrace_4==13 & race96_3==4
      replace racedif=1 if prdtrace_4>=15 & prdtrace_4<=21
      replace racedif=0 if race96_3==.
}
if ${t_4}>=517 {                        /* 0302 until end */
gen byte racedif=prdtrace_3==prdtrace_4
replace racedif=0 if prdtrace_3==.
}


* Relationship to reference person
gen byte relhhdif=0
if ${t_4}>=228 & ${t_4}<=264  {          /* 7901 until 8201 */
replace relhhdif=1 if rehh_4==rehh_3
replace relhhdif=0 if rehh_3==.
}
else if ${t_4}>=265 & ${t_4}<=347 {     /* 8202 until 8812 */
replace relhhdif=1 if rrp82_4==rrp82_3
replace relhhdif=0 if rrp82_3==.
}
else if ${t_4}==348 {                   /* 8901 */
replace relhhdif=1 if rrp89_4==rrp82_3 & rrp89_4>=1 & rrp89_4<=4 & rrp82_3>=1 & rrp82_3<=4
replace relhhdif=1 if (rrp89_4==5 | rrp89_4==6 | rrp89_4==7 | rrp89_4==11 ) & rrp82_3==5
replace relhhdif=1 if rrp89_4==8 & rrp82_3==6
replace relhhdif=1 if rrp89_4==9 & rrp82_3==7
replace relhhdif=1 if rrp89_4==10 & rrp82_3==8
replace relhhdif=1 if (rrp89_4==12 | rrp89_4==12) & rrp82_3==9
replace relhhdif=1 if (rrp89_4==14 | rrp89_4==13) & rrp82_3==0
replace relhhdif=0 if rrp82_3==.
}
else if ${t_4}>=349 & ${t_4}<=407 {     /* 8902 until 9312 */
replace relhhdif=1 if rrp89_4==rrp89_3
replace relhhdif=0 if rrp89_3==.
}
else if ${t_4}==408 {                    /* 9401 */
replace relhhdif=1 if rrp94_4==rrp89_3 & rrp94_4>=1 & rrp94_4<=2 & rrp89_3>=1 & rrp89_3<=2
replace relhhdif=1 if rrp94_4==3 & (rrp89_3==3 | rrp89_3==4)
replace relhhdif=1 if rrp94_4==4 & (rrp89_3==5 | rrp89_3==6)
gen relhhdif_help=rrp94_4+2 if rrp94_4>=5 & rrp94_4<=12
replace relhhdif_help=10 if rrp94_4==9
replace relhhdif=1 if relhhdif_help==rrp89_3 & rrp89~=.
drop relhhdif_help
replace relhhdif=0 if rrp89_3==.
}
else if ${t_4}>=409 & ${t_4}<=428 {     /* 9402 until 9509 */
replace relhhdif=1 if rrp94_4==rrp94_3
replace relhhdif=0 if rrp94_3==.
}
else if ${t_4}>=429 & ${t_4}<=554 {      /* 9510 until 0603 */
replace relhhdif=1 if rrp95_4==rrp95_3
replace relhhdif=0 if rrp95_3==.
}

gen byte agedif=age_4-age_3
gen byte ragedif=(agedif==0 | agedif==1)
tab ragedif
gen byte nragedif=(agedif==-1 | agedif==0 | agedif==1 | agedif==2)
tab nragedif

* Deal with duplicate observations
do ${do_path}multobs

* Assess merge

display "Assess merge ${x${t_4}} to ${x${t_3}}"
tab _merge
gen merge_43=_merge
tab merge_43
count if merge_43==3
gen int n_obsn_3=r(N)
gen mergern_43=n_obsn_3/n_obs_4

gen byte s_r_a_43  =(sexdif==0 | racedif==0 | ragedif==0)
gen byte any2_43 =0
  replace any2_43=1 if (sexdif==0 & racedif==0)
  replace any2_43=1 if (sexdif==0 & ragedif==0)
  replace any2_43=1 if (racedif==0 & ragedif==0)
gen byte s_2_43    =(sexdif==0 | (racedif==0 & ragedif==0) )

gen byte S_R_A_43  =(sexdif==0 | racedif==0 | nragedif==0)
gen byte ANY2_43   =0
  replace ANY2_43=1 if (sexdif==0 & racedif==0)
  replace ANY2_43=1 if (sexdif==0 & nragedif==0)
  replace ANY2_43=1 if (racedif==0 & nragedif==0)
gen byte S_2_43    =(sexdif==0 | (racedif==0 & nragedif==0))

* Delete t_3 observations which could not be matched to t_4
drop if _merge==1

* nonmatchability:
* june to july 1985
* september to october 1985
* may to june 1995
* august to september 1995
gen byte mismatch_43 = 0
replace mismatch_43 = 1 if period==306 | period==309 | period==425 | period==428

display "Merge table t_3=${x${t_3}} b"
tab _merge
display "count if s_r_a_43==0 & merge_43==3"
count if s_r_a_43==0 & merge_43==3
gen n_obs_3=r(N)
gen merger_43=n_obs_3/n_obs_4
 
sort mis state hhid hhnum lineno
assert lineno~=lineno[_n-1] if hhid==hhid[_n-1] & hhnum==hhnum[_n-1] & _merge==3, rc0

* STEP 1:
    drop _merge
    drop obsno 
cap drop obsno2
if ${t_4}>=411 & ${t_4}<=430  {
sort mis state hhid hrsersuf hhnum lineno
}
else {
sort mis state hhid hhnum lineno
}
gen obsno2=_n
save ${sav_path}m${x${t_4}}, replace

*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
*XXXXXXXXXXXXXXX SECOND PART XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

* STEP 2.1:  Load data for individuals in time t_2
display "Reading in individual data"
use ${dat_path}d_${x${t_2}} if mis==2 | mis==6, clear

replace mis=mis+2

renvars, suffix(_2)
ren state_2 state
ren hhid_2    hhid
ren hhnum_2   hhnum
ren lineno_2  lineno
ren mis_2     mis
    
* STEP 3:  Merge t2 data to t4 data
display "t_2=${x${t_2}}"
if ${t_4}>=411 & ${t_4}<=430  {
ren hrsersuf_2 hrsersuf
sort mis state hhid hrsersuf hhnum lineno
}
else {
sort mis state hhid hhnum lineno
}
gen obsno=_n

display "Merging t_4 and t_2 data"
if ${t_4}>=411 & ${t_4}<=430  {
merge mis state hhid hrsersuf hhnum lineno using ${sav_path}/m${x${t_4}}
}
else {
merge mis state hhid hhnum lineno using ${sav_path}m${x${t_4}}
}
display "Merge table t_2=${x${t_2}} a"
tab _merge
gen merge_32=_merge
drop if _merge==1
        
* STEP 4:  Define merge quality variables
* SEX
replace sexdif=sex_2==sex_3
replace sexdif=0 if sex_2==.
* RACE
if ${t_3}>=228 & ${t_3}<=263 {
replace racedif=race78_2==race78_3
replace racedif=0 if race78_2==.
}
if ${t_3}==264 {              
replace racedif=race_rcde_2==race_rcde_3
replace racedif=0 if race_rcde_2==.
}
if ${t_3}>=265 & ${t_3}<=305 {
replace racedif=race82_2==race82_3 
replace racedif=0 if race82_2==.
}
if ${t_3}>=306 & ${t_3}<=347 {
replace racedif=race_rcde_2==race_rcde_3
replace racedif=0 if race_rcde_2==.
}
if ${t_3}==348 {              
replace racedif=race_rcde_2==race82_3
replace racedif=1 if race_rcde_2==3 & (race82_3==4 | race82_3==5)
replace racedif=0 if race_rcde_2==.
}
if ${t_3}>=349 & ${t_3}<=431 {
replace racedif=race82_2==race82_3
replace racedif=0 if race82_2==.
}
if ${t_3}==432 {              
replace racedif=race82_2==race96_3
replace racedif=1 if race82_2==5
replace racedif=0 if race82_2==.
}
if ${t_3}>=433 & ${t_3}<=515 {
replace racedif=race96_2==race96_3
replace racedif=0 if race96_2==.
}
if ${t_3}==516 {              
replace racedif=race96_2==prdtrace_3
      replace racedif=1 if prdtrace_3==14 & race96_2==4
      replace racedif=1 if prdtrace_3==6  & race96_2==1
      replace racedif=1 if prdtrace_3==7  & race96_2==1
      replace racedif=1 if prdtrace_3==8  & race96_2==1
      replace racedif=1 if prdtrace_3==9  & race96_2==1
      replace racedif=1 if prdtrace_3==6  & race96_2==2
      replace racedif=1 if prdtrace_3==10 & race96_2==2
      replace racedif=1 if prdtrace_3==11 & race96_2==2
      replace racedif=1 if prdtrace_3==12 & race96_2==2
      replace racedif=1 if prdtrace_3==7  & race96_2==3
      replace racedif=1 if prdtrace_3==10 & race96_2==3
      replace racedif=1 if prdtrace_3==13 & race96_2==3
      replace racedif=1 if prdtrace_3==8  & race96_2==4
      replace racedif=1 if prdtrace_3==9  & race96_2==4
      replace racedif=1 if prdtrace_3==11 & race96_2==4
      replace racedif=1 if prdtrace_3==12 & race96_2==4
      replace racedif=1 if prdtrace_3==13 & race96_2==4
      replace racedif=1 if prdtrace_3>=15 & prdtrace_3<=21
      replace racedif=0 if race96_2==.
}
if ${t_3}>=517 {              
replace racedif=prdtrace_2==prdtrace_3
replace racedif=0 if prdtrace_2==.
}

* RELATIONSHIP TO REFERENCE PERSON
replace relhhdif=0
if ${t_3}>=228 & ${t_3}<=264  {
replace relhhdif=1 if rehh_3==rehh_2
replace relhhdif=0 if rehh_2==.
}
else if ${t_3}>=265 & ${t_3}<=347 { 
replace relhhdif=1 if rrp82_3==rrp82_2
replace relhhdif=0 if rrp82_2==.
}
else if ${t_3}==348 {               
replace relhhdif=1 if rrp89_3==rrp82_2 & rrp89_3>=1 & rrp89_3<=4 & rrp82_2>=1 & rrp82_2<=4
replace relhhdif=1 if (rrp89_3==5 | rrp89_3==6 | rrp89_3==7 | rrp89_3==11 ) & rrp82_2==5
replace relhhdif=1 if rrp89_3==8 & rrp82_2==6
replace relhhdif=1 if rrp89_3==9 & rrp82_2==7
replace relhhdif=1 if rrp89_3==10 & rrp82_2==8
replace relhhdif=1 if (rrp89_3==12 | rrp89_3==12) & rrp82_2==9
replace relhhdif=1 if (rrp89_3==14 | rrp89_3==13) & rrp82_2==0
replace relhhdif=0 if rrp82_2==.
}
else if ${t_3}>=349 & ${t_3}<=407 { 
replace relhhdif=1 if rrp89_3==rrp89_2
replace relhhdif=0 if rrp89_2==.
}
else if ${t_3}==408 {               
replace relhhdif=1 if rrp94_3==rrp89_2 & rrp94_3>=1 & rrp94_3<=2 & rrp89_2>=1 & rrp89_2<=2
replace relhhdif=1 if rrp94_3==3 & (rrp89_2==3 | rrp89_2==4)
replace relhhdif=1 if rrp94_3==4 & (rrp89_2==5 | rrp89_2==6)
gen relhhdif_help=rrp94_3+2 if rrp94_3>=5 & rrp94_3<=12
replace relhhdif_help=10 if rrp94_3==9
replace relhhdif=1 if relhhdif_help==rrp89_2 & rrp89_2~=.
drop relhhdif_help
replace relhhdif=0 if rrp89_2==.
}
else if ${t_3}>=409 & ${t_3}<=428 { 
replace relhhdif=1 if rrp94_3==rrp94_2
replace relhhdif=0 if rrp94_2==.
}
else if ${t_3}>=429 & ${t_3}<=554 { 
replace relhhdif=1 if rrp95_3==rrp95_2
replace relhhdif=0 if rrp95_2==.
}

replace agedif=age_3-age_2
replace ragedif=(agedif==0 | agedif==1)
replace nragedif=(agedif==-1 | agedif==0 | agedif==1 | agedif==2)
    
* Deal with duplicate observations
do ${do_path}multobs

* calculate "naive" mergerate
count if merge_32==3
gen int n_obsn_2=r(N)
gen mergern_32=n_obsn_2/n_obs_4

* Assess merge
display "Assess merge"

gen byte s_r_a_32=(sexdif==0 | racedif==0 | ragedif==0)
gen byte any2_32 =0
replace any2_32=1 if (sexdif==0 & racedif==0)
replace any2_32=1 if (sexdif==0 & ragedif==0)
replace any2_32=1 if (racedif==0 & ragedif==0)
gen byte s_2_32=(sexdif==0 | (racedif==0 & ragedif==0) )

gen byte S_R_A_32=(sexdif==0 | racedif==0 | nragedif==0)
gen byte ANY2_32 =0
replace ANY2_32=1 if (sexdif==0 & racedif==0)
replace ANY2_32=1 if (sexdif==0 & nragedif==0)
replace ANY2_32=1 if (racedif==0 & nragedif==0)
gen byte S_2_32=(sexdif==0 | (racedif==0 & nragedif==0))

* nonmatchability:
* june to july 1985
* september to october 1985
* may to june 1995
* august to september 1995
gen byte mismatch_32 = 0
replace mismatch_32 = 1 if period==306 | period==309 | period==425 | period==428

display "Merge table t_2=${x${t_2}} b"
tab _merge   

* calculate mergerate
count if merge_32==3 & s_r_a_32==0
gen int n_obs_2=r(N)
gen merger_32=n_obs_2/n_obs_4
 
sort mis state hhid hhnum lineno
assert lineno~=lineno[_n-1] if hhid==hhid[_n-1] & hhnum==hhnum[_n-1] & _merge==3, rc0
    
* Sort and save
display "Sorting and saving merged data"
drop _merge obsno obsno2

if ${t_4}>=411 & ${t_4}<=430  {
    sort mis state hhid hrsersuf hhnum lineno
    }
    else {
    sort mis state hhid hhnum lineno
    }
gen obsno2=_n
save ${sav_path}m${x${t_4}}, replace

*XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
*XXXXXXXXXXXXXX THIRD PART XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

* STEP 3.1:  Load data for individuals in time t_1
display "Reading in individual data"
use ${dat_path}d_${x${t_1}} if mis==1 | mis==5, clear
 
replace mis=mis+3

renvars, suffix(_1)
ren state_1 state
ren hhid_1    hhid
ren hhnum_1   hhnum
ren lineno_1  lineno
ren mis_1     mis
        
* STEP 3:  Merge t1 data to t4 data
if ${t_4}>=411 & ${t_4}<=430  {
    ren hrsersuf_1 hrsersuf
    sort mis state hhid hrsersuf hhnum lineno
    }
    else {
    sort mis state hhid hhnum lineno
    }
    gen obsno=_n
    display "Merging t_2 and t_1 data"
if ${t_4}>=411 & ${t_4}<=430  {
    merge mis state hhid hrsersuf hhnum lineno using ${sav_path}m${x${t_4}}
    }
    else {
     merge mis state hhid hhnum lineno using ${sav_path}m${x${t_4}}
    }
    
display "Merge table t_1=${x${t_1}} a"
tab _merge
drop if _merge==1
gen merge_21=_merge
    
* STEP 4:  Define merge quality variables
* SEX
replace sexdif=sex_1==sex_2
* RACE
if ${t_2}>=228 & ${t_2}<=263 {    
replace racedif=race78_1==race78_2
replace racedif=0 if race78_1==.
}
if ${t_2}==264 {                  
replace racedif=race_rcde_1==race_rcde_2
replace racedif=0 if race_rcde_1==.
}
if ${t_2}>=265 & ${t_2}<=305 {    
replace racedif=race82_1==race82_2 
replace racedif=0 if race82_1==.
}
if ${t_2}>=306 & ${t_2}<=347 {    
replace racedif=race_rcde_1==race_rcde_2
replace racedif=0 if race_rcde_1==.
}
if ${t_2}==348 {                  
replace racedif=race_rcde_1==race82_2
replace racedif=1 if race_rcde_1==3 & (race82_2==4 | race82_2==5)
replace racedif=0 if race_rcde_1==.
}
if ${t_2}>=349 & ${t_2}<=431 {    
replace racedif=race82_1==race82_2
replace racedif=0 if race82_1==.
}
if ${t_2}==432 {                  
replace racedif=race82_1==race96_2
replace racedif=1 if race82_1==5
replace racedif=0 if race82_1==.
}
if ${t_2}>=433 & ${t_2}<=515 {    
replace racedif=race96_1==race96_2
replace racedif=0 if race96_1==. 
}
if ${t_2}==516 {                  
replace racedif=race96_1==prdtrace_2
      replace racedif=1 if prdtrace_2==14 & race96_1==4
      replace racedif=1 if prdtrace_2==6  & race96_1==1
      replace racedif=1 if prdtrace_2==7  & race96_1==1
      replace racedif=1 if prdtrace_2==8  & race96_1==1
      replace racedif=1 if prdtrace_2==9  & race96_1==1
      replace racedif=1 if prdtrace_2==6  & race96_1==2
      replace racedif=1 if prdtrace_2==10 & race96_1==2
      replace racedif=1 if prdtrace_2==11 & race96_1==2
      replace racedif=1 if prdtrace_2==12 & race96_1==2
      replace racedif=1 if prdtrace_2==7  & race96_1==3
      replace racedif=1 if prdtrace_2==10 & race96_1==3
      replace racedif=1 if prdtrace_2==13 & race96_1==3
      replace racedif=1 if prdtrace_2==8  & race96_1==4
      replace racedif=1 if prdtrace_2==9  & race96_1==4
      replace racedif=1 if prdtrace_2==11 & race96_1==4
      replace racedif=1 if prdtrace_2==12 & race96_1==4
      replace racedif=1 if prdtrace_2==13 & race96_1==4
      replace racedif=1 if prdtrace_2>=15 & prdtrace_2<=21
      replace racedif=0 if race96_1==.
}
if ${t_2}>=517 {                  
replace racedif=prdtrace_1==prdtrace_2
replace racedif=0 if prdtrace_1==.
}

* RELATIONSHIP TO REFERENCE PERSON
replace relhhdif=0
if ${t_2}>=228 & ${t_2}<=264  {   
replace relhhdif=1 if rehh_2==rehh_1
replace relhhdif=0 if rehh_1==.
}
else if ${t_2}>=265 & ${t_2}<=347 { 
replace relhhdif=1 if rrp82_2==rrp82_1
replace relhhdif=0 if rrp82_1==.
}
else if ${t_2}==348 {               
replace relhhdif=1 if rrp89_2==rrp82_1 & rrp89_2>=1 & rrp89_2<=4 & rrp82_1>=1 & rrp82_1<=4
replace relhhdif=1 if (rrp89_2==5 | rrp89_2==6 | rrp89_2==7 | rrp89_2==11 ) & rrp82_1==5
replace relhhdif=1 if rrp89_2==8 & rrp82_1==6
replace relhhdif=1 if rrp89_2==9 & rrp82_1==7
replace relhhdif=1 if rrp89_2==10 & rrp82_1==8
replace relhhdif=1 if (rrp89_2==12 | rrp89_2==12) & rrp82_1==9
replace relhhdif=1 if (rrp89_2==14 | rrp89_2==13) & rrp82_1==0
replace relhhdif=0 if rrp82_1==.
}
else if ${t_2}>=349 & ${t_2}<=407 { 
replace relhhdif=1 if rrp89_2==rrp89_1
replace relhhdif=0 if rrp89_1==.
}
else if ${t_2}==408 {               
replace relhhdif=1 if rrp94_2==rrp89_1 & rrp94_2>=1 & rrp94_2<=2 & rrp89_1>=1 & rrp89_1<=2
replace relhhdif=1 if rrp94_2==3 & (rrp89_1==3 | rrp89_1==4)
replace relhhdif=1 if rrp94_2==4 & (rrp89_1==5 | rrp89_1==6)
gen relhhdif_help=rrp94_2+2 if rrp94_2>=5 & rrp94_2<=12
replace relhhdif_help=10 if rrp94_2==9
replace relhhdif=1 if relhhdif_help==rrp89_1 & rrp89~=.
drop relhhdif_help
replace relhhdif=0 if rrp89_1==.
}
else if ${t_2}>=409 & ${t_2}<=428 { 
replace relhhdif=1 if rrp94_2==rrp94_1
replace relhhdif=0 if rrp94_1==.
}
else if ${t_2}>=429 & ${t_2}<=554 { 
replace relhhdif=1 if rrp95_2==rrp95_1
replace relhhdif=0 if rrp95_1==.
}

* AGE 
replace agedif=age_2-age_1
replace ragedif=(agedif==0 | agedif==1)
replace nragedif=(agedif==-1 | agedif==0 | agedif==1 | agedif==2)
    
* Deal with duplicate observations
do ${do_path}multobs

* calculate "naive" mergerate
count if merge_21==3
gen int n_obsn_1=r(N)
gen mergern_21=n_obsn_1/n_obs_4

* Assess merge
display "Assess merge"

gen byte s_r_a_21  =(sexdif==0 | racedif==0 | ragedif==0)
gen byte any2_21 =0
replace any2_21=1 if (sexdif==0 & racedif==0)
replace any2_21=1 if (sexdif==0 & ragedif==0)
replace any2_21=1 if (racedif==0 & ragedif==0)
gen byte s_2_21    =(sexdif==0 | (racedif==0 & ragedif==0) )

gen byte S_R_A_21  =(sexdif==0 | racedif==0 | nragedif==0)
gen byte ANY2_21   =0
replace  ANY2_21=1 if (sexdif==0 & racedif==0)
replace  ANY2_21=1 if (sexdif==0 & nragedif==0)
replace  ANY2_21=1 if (racedif==0 & nragedif==0)
gen byte S_2_21    =(sexdif==0 | (racedif==0 & nragedif==0))

* nonmatchability:
* june to july 1985
* september to october 1985
* may to june 1995
* august to september 1995
gen byte mismatch_21 = 0
replace mismatch_21 = 1 if period==306 | period==309 | period==425 | period==428

display "Merge table t_1=${x${t_1}} b"
tab _merge   
count if merge_21==3 & s_r_a_21==0
gen int n_obs_1=r(N)
gen merger_21=n_obs_1/n_obs_4 
 
sort mis state hhid hhnum lineno
assert lineno~=lineno[_n-1] if hhid==hhid[_n-1] & hhnum==hhnum[_n-1] & _merge==3, rc0
drop _merge
drop *dif

* Sort and save
compress
display "Sorting and saving merged data"
* sort state hhid hhnum lineno
save ${sav_path}m${x${t_4}}, replace

end

global  x225    7810
global  x226    7811
global  x227    7812
global  x228    7901
global  x229    7902
global  x230    7903
global  x231    7904
global  x232    7905
global  x233    7906
global  x234    7907
global  x235    7908
global  x236    7909
global  x237    7910
global  x238    7911
global  x239    7912
global  x240    8001
global  x241    8002
global  x242    8003
global  x243    8004
global  x244    8005
global  x245    8006
global  x246    8007
global  x247    8008
global  x248    8009
global  x249    8010
global  x250    8011
global  x251    8012
global  x252    8101
global  x253    8102
global  x254    8103
global  x255    8104
global  x256    8105
global  x257    8106
global  x258    8107
global  x259    8108
global  x260    8109
global  x261    8110
global  x262    8111
global  x263    8112
global  x264    8201
global  x265    8202
global  x266    8203
global  x267    8204
global  x268    8205
global  x269    8206
global  x270    8207
global  x271    8208
global  x272    8209
global  x273    8210
global  x274    8211
global  x275    8212
global  x276    8301
global  x277    8302
global  x278    8303
global  x279    8304
global  x280    8305
global  x281    8306
global  x282    8307
global  x283    8308
global  x284    8309
global  x285    8310
global  x286    8311
global  x287    8312
global  x288    8401
global  x289    8402
global  x290    8403
global  x291    8404
global  x292    8405
global  x293    8406
global  x294    8407
global  x295    8408
global  x296    8409
global  x297    8410
global  x298    8411
global  x299    8412
global  x300    8501
global  x301    8502
global  x302    8503
global  x303    8504
global  x304    8505
global  x305    8506
global  x306    8507
global  x307    8508
global  x308    8509
global  x309    8510
global  x310    8511
global  x311    8512
global  x312    8601
global  x313    8602
global  x314    8603
global  x315    8604
global  x316    8605
global  x317    8606
global  x318    8607
global  x319    8608
global  x320    8609
global  x321    8610
global  x322    8611
global  x323    8612
global  x324    8701
global  x325    8702
global  x326    8703
global  x327    8704
global  x328    8705
global  x329    8706
global  x330    8707
global  x331    8708
global  x332    8709
global  x333    8710
global  x334    8711
global  x335    8712
global  x336    8801
global  x337    8802
global  x338    8803
global  x339    8804
global  x340    8805
global  x341    8806
global  x342    8807
global  x343    8808
global  x344    8809
global  x345    8810
global  x346    8811
global  x347    8812
global  x348    8901
global  x349    8902
global  x350    8903
global  x351    8904
global  x352    8905
global  x353    8906
global  x354    8907
global  x355    8908
global  x356    8909
global  x357    8910
global  x358    8911
global  x359    8912
global  x360    9001
global  x361    9002
global  x362    9003
global  x363    9004
global  x364    9005
global  x365    9006
global  x366    9007
global  x367    9008
global  x368    9009
global  x369    9010
global  x370    9011
global  x371    9012
global  x372    9101
global  x373    9102
global  x374    9103
global  x375    9104
global  x376    9105
global  x377    9106
global  x378    9107
global  x379    9108
global  x380    9109
global  x381    9110
global  x382    9111
global  x383    9112
global  x384    9201
global  x385    9202
global  x386    9203
global  x387    9204
global  x388    9205
global  x389    9206
global  x390    9207
global  x391    9208
global  x392    9209
global  x393    9210
global  x394    9211
global  x395    9212
global  x396    9301
global  x397    9302
global  x398    9303
global  x399    9304
global  x400    9305
global  x401    9306
global  x402    9307
global  x403    9308
global  x404    9309
global  x405    9310
global  x406    9311
global  x407    9312
global  x408    9401
global  x409    9402
global  x410    9403
global  x411    9404
global  x412    9405
global  x413    9406
global  x414    9407
global  x415    9408
global  x416    9409
global  x417    9410
global  x418    9411
global  x419    9412
global  x420    9501
global  x421    9502
global  x422    9503
global  x423    9504
global  x424    9505
global  x425    9506
global  x426    9507
global  x427    9508
global  x428    9509
global  x429    9510
global  x430    9511
global  x431    9512
global  x432    9601
global  x433    9602
global  x434    9603
global  x435    9604
global  x436    9605
global  x437    9606
global  x438    9607
global  x439    9608
global  x440    9609
global  x441    9610
global  x442    9611
global  x443    9612
global  x444    9701
global  x445    9702
global  x446    9703
global  x447    9704
global  x448    9705
global  x449    9706
global  x450    9707
global  x451    9708
global  x452    9709
global  x453    9710
global  x454    9711
global  x455    9712
global  x456    9801
global  x457    9802
global  x458    9803
global  x459    9804
global  x460    9805
global  x461    9806
global  x462    9807
global  x463    9808
global  x464    9809
global  x465    9810
global  x466    9811
global  x467    9812
global  x468    9901
global  x469    9902
global  x470    9903
global  x471    9904
global  x472    9905
global  x473    9906
global  x474    9907
global  x475    9908
global  x476    9909
global  x477    9910
global  x478    9911
global  x479    9912
global  x480    0001
global  x481    0002
global  x482    0003
global  x483    0004
global  x484    0005
global  x485    0006
global  x486    0007
global  x487    0008
global  x488    0009
global  x489    0010
global  x490    0011
global  x491    0012
global  x492    0101
global  x493    0102
global  x494    0103
global  x495    0104
global  x496    0105
global  x497    0106
global  x498    0107
global  x499    0108
global  x500    0109
global  x501    0110
global  x502    0111
global  x503    0112
global  x504    0201
global  x505    0202
global  x506    0203
global  x507    0204
global  x508    0205
global  x509    0206
global  x510    0207
global  x511    0208
global  x512    0209
global  x513    0210
global  x514    0211
global  x515    0212
global  x516    0301
global  x517    0302
global  x518    0303
global  x519    0304
global  x520    0305
global  x521    0306
global  x522    0307
global  x523    0308
global  x524    0309
global  x525    0310
global  x526    0311
global  x527    0312
global  x528    0401
global  x529    0402
global  x530    0403
global  x531    0404
global  x532    0405
global  x533    0406
global  x534    0407
global  x535    0408
global  x536    0409
global  x537    0410
global  x538    0411
global  x539    0412
global  x540    0501
global  x541    0502
global  x542    0503
global  x543    0504
global  x544    0505
global  x545    0506
global  x546    0507
global  x547    0508
global  x548    0509
global  x549    0510
global  x550    0511
global  x551    0512
global  x552    0601
global  x553    0602
global  x554    0603
global  x555    0604
global  x556    0605
global  x557    0606
global  x558    0607


* RUN THE PROGRAM

forvalues i=228/558 {
mergecps `i'
}

* * calculate overall matchrate
* global merge_4_acc= ${merge_4_291} 
* global mergen_43_acc=${mergen_43_291}
* global mergen_32_acc=${mergen_32_291}
* global mergen_21_acc=${mergen_21_291}
* global mergeinc_4_acc=${mergeinc_4_291}
* global mergeninc_43_acc=${mergeninc_43_291}
* global mergeninc_32_acc=${mergeninc_32_291}
* global mergeninc_21_acc=${mergeninc_21_291}
* global merge_43_acc=${merge_43_291}
* global merge_32_acc=${merge_32_291}
* global merge_21_acc=${merge_21_291}
* global mergeinc_43_acc=${mergeinc_43_291}
* global mergeinc_32_acc=${mergeinc_32_291}
* global mergeinc_21_acc=${mergeinc_21_291}
* 
* global match_acc
* forvalues i=292/293 {
* global j `i'
* global merge_4_acc=${merge_4_acc}+${merge_4_${j}}
* global mergen_43_acc=${mergen_43_acc}+${mergen_43_${j}}
* global mergen_32_acc=${mergen_32_acc}+${mergen_32_${j}}
* global mergen_21_acc=${mergen_21_acc}+${mergen_21_${j}}
* global mergeinc_4_acc=${mergeinc_4_acc}+${mergeinc_4_${j}}
* global mergeninc_43_acc=${mergeninc_43_acc}+${mergeninc_43_${j}}
* global mergeninc_32_acc=${mergeninc_32_acc}+${mergeninc_32_${j}}
* global mergeninc_21_acc=${mergeninc_21_acc}+${mergeninc_21_${j}}
* global merge_43_acc=${merge_43_acc}+${merge_43_${j}}
* global merge_32_acc=${merge_32_acc}+${merge_32_${j}}
* global merge_21_acc=${merge_21_acc}+${merge_21_${j}}
* global mergeinc_43_acc=${mergeinc_43_acc}+${mergeinc_43_${j}}
* global mergeinc_32_acc=${mergeinc_32_acc}+${mergeinc_32_${j}}
* global mergeinc_21_acc=${mergeinc_21_acc}+${mergeinc_21_${j}}
* }
* 
* global mergeraten_acc=(${mergen_43_acc}+${mergen_32_acc}+${mergen_21_acc})/(${merge_4_acc}+${merge_43_acc}+${merge_32_acc})
* global mergerate_acc =(${merge_43_acc} +${merge_32_acc}+${merge_21_acc})/(${merge_4_acc}+${merge_43_acc}+${merge_32_acc})
* global mergerateninc_acc=(${mergeninc_43_acc}+${mergeninc_32_acc}+${mergeninc_21_acc})/(${mergeinc_4_acc}+${mergeinc_43_acc}+${mergeinc_32_acc})
* global mergerateinc_acc =(${mergeinc_43_acc}+${mergeinc_32_acc}+${mergeinc_21_acc})/(${mergeinc_4_acc}+${mergeinc_43_acc}+${mergeinc_32_acc})
* 
* global mergeraten_43_acc=${mergen_43_acc}/${merge_4_acc}
* global mergeraten_32_acc=${mergen_32_acc}/${merge_4_acc}
* global mergeraten_21_acc=${mergen_21_acc}/${merge_4_acc}
* 
* global mergerate_43_acc=${merge_43_acc}/${merge_4_acc}
* global mergerate_32_acc=${merge_32_acc}/${merge_4_acc}
* global mergerate_21_acc=${merge_21_acc}/${merge_4_acc}
* 
* global mergerateninc_43_acc=${mergeninc_43_acc}/${mergeinc_4_acc}
* global mergerateninc_32_acc=${mergeninc_32_acc}/${mergeinc_4_acc}
* global mergerateninc_21_acc=${mergeninc_21_acc}/${mergeinc_4_acc}
* 
* global mergerateinc_43_acc=${mergeinc_43_acc}/${mergeinc_4_acc}
* global mergerateinc_32_acc=${mergeinc_32_acc}/${mergeinc_4_acc}
* global mergerateinc_21_acc=${mergeinc_21_acc}/${mergeinc_4_acc}


 
